
#include <stdio.h>
#include <string.h>
#include "zlib.h"
#include "system.h"
#include "video.h"
#include "audio.h"
#include "config.h"
#include "language.h"
#include "cheat.h"
#include "def.h"

struct _SYSTEM System;
struct _JOYPAD Joypad[2];

int  PSGBuf   [2][AUDIO_BLOCKLENGTH];
int  YM2413Buf[2][AUDIO_BLOCKLENGTH];
BOOL PSGBuf_NULL    = FALSE;
BOOL YM2413Buf_NULL = FALSE;

unsigned char DummyWrite[0x2000];

BOOL System_On  = FALSE;
BOOL YM2413Init = FALSE;

extern const unsigned char Bios13[0x2000];

void System_Reset(BOOL bios)
{
  memset(&System, 0, sizeof(struct _SYSTEM));

  // start Z80
  Z80.IPeriod = CYCLES_PER_LINE;
  ResetZ80();
  VDP_Init();
  Render_Init();
  PSG_Init(MASTER_CLOCK, 44100);
  if(EnableYM2413)
  {
    if(!YM2413Init) { YM2413_Init(MASTER_CLOCK, 44100); YM2413Init = TRUE; }
    else
    {
      YM2413_Reset();
      YM2413_ResetPatch(0);
    }
  }

  if(Cart.Type == CART_TYPE_GG) System.Flags |= SF_GAME_GEAR;

  // init memory map
  if(!(System.Flags & SF_GAME_GEAR) && bios)
  {
    memset(DummyWrite, 0, 0x2000);
    RdMap[0] = (unsigned char *)Bios13;
    RdMap[1] = DummyWrite;
    RdMap[2] = DummyWrite;
    RdMap[3] = DummyWrite;
    RdMap[4] = DummyWrite;
    RdMap[5] = DummyWrite;
    System.Flags |= SF_BIOS;
  }
  else
  {
    RdMap[0] = Cart.ROM + 0x0000;
    RdMap[1] = Cart.ROM + 0x2000;
    RdMap[2] = Cart.ROM + 0x4000;
    RdMap[3] = Cart.ROM + 0x6000;
    RdMap[4] = Cart.ROM + 0x8000;
    RdMap[5] = Cart.ROM + 0xA000;
  }
  RdMap[6] = System.RAM;
  RdMap[7] = System.RAM;
  WrMap[0] = DummyWrite;
  WrMap[1] = DummyWrite;
  WrMap[2] = DummyWrite;
  WrMap[3] = DummyWrite;
  WrMap[4] = DummyWrite;
  WrMap[5] = DummyWrite;
  WrMap[6] = System.RAM;
  WrMap[7] = System.RAM;

  System.FCR[2] = 1;
  memset(Joypad, 0, sizeof(struct _JOYPAD) * 2);
}

BOOL System_Init(const char *rom_name)
{
  char fn[MAX_PATH];

  System_Quit();
  // trying to load ROM
  if(!Cart_LoadROM(rom_name)) return FALSE;
  // loading SRAM
  sprintf(fn, "%s%.8lX.srm", SRAMFolder, Cart.CRC);
  Cart_LoadSRAM(fn);
  // reset system
  System_Reset(RunBios);
  // trying to load cheats
  sprintf(fn, "%s%.8lX%s", CheatFolder, Cart.CRC, ".c");
  Cheat_Init(fn);

  return System_On = TRUE;
}

void System_Quit(void)
{
  char fn[MAX_PATH];
  // saving SRAM
  if(Cart_Loaded)
  {
    sprintf(fn, "%s%.8lX.srm", SRAMFolder, Cart.CRC);
    Cart_SaveSRAM(fn);
    Cart_FreeROM();
  }
  Cheat_Quit();
  memset(&System, 0, sizeof(struct _SYSTEM));
  System_On = FALSE;
}

BOOL System_Frame(BOOL fast)
{
  if(!System_On) return FALSE;

  if(!(System.Flags & SF_GAME_GEAR))
  {
    if(Joypad[0].Start || Joypad[1].Start)
    {
      if(!(System.Flags & SF_PAUSED))
      {
        System.Flags |= SF_PAUSED;
        IntZ80(INT_NMI);
      }
    }
    else System.Flags &= ~SF_PAUSED;
  }

  if(fast)
  {
    for(VDP.Line = 0; VDP.Line < 262; VDP.Line++)
    {
      VDP_Run();
      RunZ80();
    }
    Audio_Buffer.CurrentPosition = Audio_Buffer.Data;
    Audio_Buffer.Filled = 0;
  }
  else
  {
    if(System.Flags & SF_GAME_GEAR)
      for(VDP.Line = 0; VDP.Line < 262; VDP.Line++)
      {
        VDP_Run();
        Render_GGLine();
        RunZ80();
      }
    else
      for(VDP.Line = 0; VDP.Line < 262; VDP.Line++)
      {
        VDP_Run();
        Render_SMSLine();
        RunZ80();
      }

    if(EnablePSG || EnableYM2413)
    {
      short *dst;
      int    i, l, r, len, rest, *buf[2];

      Audio_Lock();

      dst  = Audio_Buffer.CurrentPosition;
      rest = AUDIO_BUFFERLENGTH - (Audio_Buffer.Filled >> 2);
      len  = AUDIO_BLOCKLENGTH < rest ? AUDIO_BLOCKLENGTH : rest;
      if(EnablePSG)
      {
        buf[0] = PSGBuf[0]; buf[1] = PSGBuf[1];
        PSG_Update(buf, len);
        PSGBuf_NULL = FALSE;
      }
      else if(!PSGBuf_NULL) { memset(PSGBuf, 0, sizeof(PSGBuf)); PSGBuf_NULL = TRUE; }
      if(EnableYM2413)
      {
        buf[0] = YM2413Buf[0]; buf[1] = YM2413Buf[1];
        YM2413_Update(buf, len);
        YM2413Buf_NULL = FALSE;
      }
      else if(!YM2413Buf_NULL) { memset(YM2413Buf, 0, sizeof(YM2413Buf)); YM2413Buf_NULL = TRUE; }

      for(i = 0; i < len; i++)
      {
        l = (PSGBuf[0][i] + YM2413Buf[0][i]) * SoundVolume;
        r = (PSGBuf[1][i] + YM2413Buf[1][i]) * SoundVolume;
        if     (l > 32767)  *dst++ = 0x7FFF;
        else if(l < -32768) *dst++ = 0x8000;
        else                *dst++ = (short)l;
        if     (r > 32767)  *dst++ = 0x7FFF;
        else if(r < -32768) *dst++ = 0x8000;
        else                *dst++ = (short)r;
      }

      Audio_Buffer.CurrentPosition = dst;
      Audio_Buffer.Filled         += len * 4;
      Audio_Unlock();
    }
  }

  Cheat_Apply();

  return TRUE;
}

const unsigned long System_StateFileID      = 0x004D5350;
const unsigned long System_StateFileVersion = 0x00000001;

BOOL System_SaveState(const char *file)
{
  gzFile        f;
  unsigned char buf[4];

  if(!System_On || (System.Flags & SF_BIOS)) return FALSE;

  f = gzopen(file, "wb");
  if(!f) return FALSE;
  
  if(gzwrite(f, &System_StateFileID, 4) != 4)      return gzclose(f), remove(file), FALSE;
  if(gzwrite(f, &System_StateFileVersion, 4) != 4) return gzclose(f), remove(file), FALSE;
  
  if(gzwrite(f, &Z80, sizeof(struct _Z80) - (1 * 4)) != sizeof(struct _Z80) - (1 * 4)) return gzclose(f), remove(file), FALSE;
  if(gzwrite(f, System.FCR, 4) != 4) return gzclose(f), remove(file), FALSE;
  buf[0] = System.Port3F;
  buf[1] = System.PortF2;
  buf[2] = System.YM2413_Latch;
  buf[3] = System.Flags;
  if(gzwrite(f, buf, 4) != 4) return gzclose(f), remove(file), FALSE;
  if(gzwrite(f, &PSG, sizeof(struct _PSG)) != sizeof(struct _PSG)) return gzclose(f), remove(file), FALSE;
  if(gzwrite(f, YM2413.reg, 64) != 64) return gzclose(f), remove(file), FALSE;
  buf[0] = buf[1] = buf[2] = buf[3] = 0;
  if(gzwrite(f, buf, 4) != 4) return gzclose(f), remove(file), FALSE;
  if(gzwrite(f, &VDP, sizeof(struct _VDP)) != sizeof(struct _VDP)) return gzclose(f), remove(file), FALSE;
  if(gzwrite(f, System.RAM, 0x2000) != 0x2000) return gzclose(f), remove(file), FALSE;
  if(gzwrite(f, Cart.SRAM, 0x8000) != 0x8000) return gzclose(f), remove(file), FALSE;
  
  gzclose(f);

  return TRUE;
}

BOOL System_LoadState(const char *file)
{
  gzFile        f;
  unsigned long id, ver;
  int           i;
  unsigned char buf[4];

  if(!System_On) return FALSE;

  f = gzopen(file, "rb");
  if(!f) return FALSE;

  if(gzread(f, &id, 4) != 4)         return gzclose(f), FALSE;
  if(id != System_StateFileID)       return gzclose(f), FALSE;
  if(gzread(f, &ver, 4) != 4)        return gzclose(f), FALSE;
  if(ver != System_StateFileVersion) return gzclose(f), FALSE;

  if(gzread(f, &Z80, sizeof(struct _Z80) - (1 * 4)) != sizeof(struct _Z80) - (1 * 4)) return gzclose(f), FALSE;
  if(gzread(f, System.FCR, 4) != 4) return gzclose(f), FALSE;
  if(gzread(f, buf, 4) != 4) return gzclose(f), FALSE;
  System.Port3F       = buf[0];
  System.PortF2       = buf[1];
  System.YM2413_Latch = buf[2];
  System.Flags        = buf[3];
  if(gzread(f, &PSG, sizeof(struct _PSG)) != sizeof(struct _PSG)) return gzclose(f), FALSE;
  if(gzread(f, YM2413.reg, 64) != 64) return gzclose(f), FALSE;
  if(gzread(f, buf, 4) != 4) return gzclose(f), FALSE;
  if(gzread(f, &VDP, sizeof(struct _VDP)) != sizeof(struct _VDP)) return gzclose(f), FALSE;
  if(gzread(f, System.RAM, 0x2000) != 0x2000) return gzclose(f), FALSE;
  if(gzread(f, Cart.SRAM, 0x8000) != 0x8000) return gzclose(f), FALSE;
  
  gzclose(f);

  RdMap[0] = Cart.ROM + 0x0000;
  RdMap[1] = Cart.ROM + 0x2000;
  RdMap[2] = Cart.ROM + 0x4000;
  RdMap[3] = Cart.ROM + 0x6000;
  RdMap[4] = Cart.ROM + 0x8000;
  RdMap[5] = Cart.ROM + 0xA000;
  RdMap[6] = System.RAM;
  RdMap[7] = System.RAM;
  WrMap[0] = DummyWrite;
  WrMap[1] = DummyWrite;
  WrMap[2] = DummyWrite;
  WrMap[3] = DummyWrite;
  WrMap[4] = DummyWrite;
  WrMap[5] = DummyWrite;
  WrMap[6] = System.RAM;
  WrMap[7] = System.RAM;

  System_MapZ80Mem(0xFFFF, System.FCR[3]);
  System_MapZ80Mem(0xFFFE, System.FCR[2]);
  System_MapZ80Mem(0xFFFD, System.FCR[1]);
  System_MapZ80Mem(0xFFFC, System.FCR[0]);

  BGListIndex = 0x200;
  for(i = 0; i < 0x200; i++)
  {
    BGNameList[i]  = i;
    BGNameDirty[i] = 0xFF;
  }
  for(i = 0; i < 32; i++) Render_PaletteSync(i);

  return TRUE;
}

void System_MapZ80Mem(word Addr, byte Value)
{
  int Page;

  System.FCR[Addr & 0x0003] = Value;

  switch(Addr)
  {
    case 0xFFFC:
      if(Value & 0x08)
      {
        if(Value & 0x04)
        {
          WrMap[4] = RdMap[4] = Cart.SRAM + 0x4000;
          WrMap[5] = RdMap[5] = Cart.SRAM + 0x6000;
          return;
        }
        else
        {
          WrMap[4] = RdMap[4] = Cart.SRAM + 0x0000;
          WrMap[5] = RdMap[5] = Cart.SRAM + 0x2000;
          return;
        }
      }
      else
      {
        Page = (System.FCR[3] % (Cart.Size >> 14)) << 14;
        RdMap[4] = Cart.ROM + Page + 0x0000;
        RdMap[5] = Cart.ROM + Page + 0x2000;
        WrMap[4] = DummyWrite;
        WrMap[5] = DummyWrite;
        return;
      }
      return;

    case 0xFFFD:
      Page = (Value % (Cart.Size >> 14)) << 14;
      RdMap[0] = Cart.ROM + Page + 0x0000;
      RdMap[1] = Cart.ROM + Page + 0x2000;
      WrMap[0] = DummyWrite;
      WrMap[1] = DummyWrite;
      return;

    case 0xFFFE:
      Page = (Value % (Cart.Size >> 14)) << 14;
      RdMap[2] = Cart.ROM + Page + 0x0000;
      RdMap[3] = Cart.ROM + Page + 0x2000;
      WrMap[0] = DummyWrite;
      WrMap[1] = DummyWrite;
      return;

    case 0xFFFF:
      if(System.FCR[0] & 0x08)
      {
        // FIXME
        if(System.FCR[0] & 0x04)
        {
          WrMap[4] = RdMap[4] = Cart.SRAM + 0x4000;
          WrMap[5] = RdMap[5] = Cart.SRAM + 0x6000;
          return;
        }
        else
        {
          WrMap[4] = RdMap[4] = Cart.SRAM + 0x0000;
          WrMap[5] = RdMap[5] = Cart.SRAM + 0x2000;
          return;
        }
      }
      else
      {
        Page = (Value % (Cart.Size >> 14)) << 14;
        RdMap[4] = Cart.ROM + Page + 0x0000;
        RdMap[5] = Cart.ROM + Page + 0x2000;
        WrMap[4] = DummyWrite;
        WrMap[5] = DummyWrite;
        return;
      }
      return;
  }
}

const unsigned char Bios13[0x2000] = {
  0xF3, 0xED, 0x56, 0x31, 0xF0, 0xDF, 0x18, 0x65, 0xF5, 0xE7, 0xF1, 0xD3, 0xBE, 0xC9, 0xFF, 0xFF,  // 0000
  0xE7, 0xAF, 0x0E, 0xBE, 0xED, 0xA3, 0xF5, 0xF1, 0xED, 0x79, 0x20, 0xF8, 0xC9, 0x11, 0xE0, 0x81,  // 0010
  0x7B, 0xD3, 0xBF, 0x7A, 0xD3, 0xBF, 0xC9, 0xFF, 0xE7, 0x79, 0xB7, 0x28, 0x01, 0x04, 0x7D, 0xD3,  // 0020
  0xBE, 0x0D, 0x20, 0xFB, 0x10, 0xF9, 0xC9, 0xFF, 0xC3, 0xB7, 0x03, 0xE7, 0x79, 0xB7, 0x28, 0x01,  // 0030
  0x04, 0x78, 0x41, 0x0E, 0xBE, 0xED, 0xA3, 0x20, 0xFC, 0x3D, 0x20, 0xF9, 0xC9, 0x21, 0x00, 0xC3,  // 0040
  0x11, 0x00, 0x7F, 0x01, 0xBE, 0x64, 0xE7, 0xED, 0xB3, 0x21, 0x80, 0xC3, 0x11, 0x80, 0x7F, 0x06,  // 0050
  0x80, 0xE7, 0xED, 0xB3, 0xC9, 0xFF, 0xED, 0x45, 0x11, 0xA0, 0x81, 0x18, 0xB3, 0x21, 0xD1, 0x08,  // 0060
  0x0E, 0x7F, 0x06, 0x04, 0xED, 0xB3, 0x21, 0x80, 0x04, 0x01, 0xBF, 0x18, 0xED, 0xB3, 0xAF, 0xD3,  // 0070
  0xBE, 0x21, 0x00, 0xC0, 0x11, 0x01, 0xC0, 0x01, 0xFF, 0x1F, 0x36, 0x00, 0xED, 0xB0, 0x06, 0x0E,  // 0080
  0xCD, 0x66, 0x03, 0x21, 0x80, 0x04, 0x01, 0xBF, 0x18, 0xED, 0xB3, 0xAF, 0xD3, 0xBE, 0x21, 0x94,  // 0090
  0x03, 0x22, 0x03, 0xC2, 0x3E, 0xD0, 0x32, 0x00, 0xC3, 0xFB, 0x3E, 0x03, 0xCD, 0x26, 0x04, 0xF3,  // 00A0
  0x11, 0x00, 0x40, 0x01, 0x20, 0x00, 0xEF, 0xCD, 0xE6, 0x04, 0x11, 0xE0, 0x67, 0x01, 0x20, 0x00,  // 00B0
  0xEF, 0x21, 0x04, 0x17, 0x11, 0x60, 0x43, 0x01, 0x28, 0x02, 0x3E, 0x09, 0xCD, 0x61, 0x04, 0x21,  // 00C0
  0x2C, 0x19, 0x11, 0x00, 0x4C, 0xCD, 0x98, 0x04, 0xAF, 0x32, 0x02, 0xC2, 0x11, 0x16, 0x7A, 0x21,  // 00D0
  0xBB, 0x0F, 0x01, 0x0A, 0x04, 0xCD, 0x51, 0x04, 0x3E, 0x81, 0x32, 0x00, 0xCF, 0x11, 0xC0, 0x4E,  // 00E0
  0x21, 0x28, 0x10, 0xCD, 0x98, 0x04, 0x21, 0xC5, 0x15, 0x11, 0x60, 0x40, 0xCD, 0x98, 0x04, 0xCD,  // 00F0
  0x20, 0x05, 0xCD, 0x1D, 0x00, 0xCD, 0xFD, 0x04, 0xF3, 0x21, 0x89, 0x02, 0x11, 0x00, 0xC7, 0x01,  // 0100
  0xDD, 0x00, 0xED, 0xB0, 0xCD, 0x00, 0xC7, 0xF3, 0x3A, 0x00, 0xC0, 0xB7, 0xD3, 0xFF/*0x28, 0x1A*/, 0x2A, 0x70,  // 0110
  0xC2, 0xED, 0x5B, 0x6A, 0xC2, 0xB7, 0xED, 0x52, 0xCA, 0xD1, 0xC7, 0xCD, 0xE6, 0x04, 0x21, 0x76,  // 0120
  0x01, 0x06, 0x03, 0xCD, 0x6A, 0x01, 0x18, 0xFE, 0xCD, 0x62, 0x01, 0xFB, 0x3E, 0x80, 0xCD, 0x26,  // 0130
  0x04, 0x3A, 0x07, 0xC2, 0xE6, 0x31, 0xFE, 0x31, 0xCA, 0x90, 0x0B, 0x18, 0xEE, 0x11, 0x54, 0x7D,  // 0140
  0x06, 0x0B, 0x21, 0x57, 0x01, 0xD7, 0xC9, 0x1B, 0x20, 0x1C, 0x1D, 0x1E, 0x1F, 0x20, 0x31, 0x39,  // 0150
  0x38, 0x36, 0xCD, 0xE6, 0x04, 0x06, 0x0C, 0x21, 0xA3, 0x01, 0xC5, 0x5E, 0x23, 0x56, 0x23, 0x46,  // 0160
  0x23, 0xD7, 0xC1, 0x10, 0xF5, 0xC9, 0x84, 0x78, 0x19, 0x4D, 0x41, 0x53, 0x54, 0x45, 0x52, 0x20,  // 0170
  0x53, 0x59, 0x53, 0x54, 0x45, 0x4D, 0x20, 0x1B, 0x20, 0x1C, 0x1D, 0x1E, 0x1F, 0x20, 0x31, 0x39,  // 0180
  0x38, 0x36, 0x04, 0x79, 0x0E, 0x53, 0x4F, 0x46, 0x54, 0x57, 0x41, 0x52, 0x45, 0x20, 0x45, 0x52,  // 0190
  0x52, 0x4F, 0x52, 0x34, 0x78, 0x04, 0x56, 0x31, 0x2E, 0x33, 0x84, 0x78, 0x13, 0x57, 0x45, 0x4C,  // 01A0
  0x43, 0x4F, 0x4D, 0x45, 0x20, 0x54, 0x4F, 0x20, 0x54, 0x48, 0x45, 0x20, 0x53, 0x45, 0x47, 0x41,  // 01B0
  0x04, 0x79, 0x0E, 0x4D, 0x41, 0x53, 0x54, 0x45, 0x52, 0x20, 0x53, 0x59, 0x53, 0x54, 0x45, 0x4D,  // 01C0
  0x2E, 0xC4, 0x79, 0x19, 0x54, 0x4F, 0x20, 0x50, 0x4C, 0x41, 0x59, 0x2C, 0x4A, 0x55, 0x53, 0x54,  // 01D0
  0x20, 0x46, 0x4F, 0x4C, 0x4C, 0x4F, 0x57, 0x20, 0x54, 0x48, 0x45, 0x53, 0x45, 0x44, 0x7A, 0x0D,  // 01E0
  0x49, 0x4E, 0x53, 0x54, 0x52, 0x55, 0x43, 0x54, 0x49, 0x4F, 0x4E, 0x53, 0x3A, 0x04, 0x7B, 0x19,  // 01F0
  0x31, 0x2E, 0x54, 0x55, 0x52, 0x4E, 0x20, 0x4F, 0x46, 0x46, 0x20, 0x50, 0x4F, 0x57, 0x45, 0x52,  // 0200
  0x20, 0x4F, 0x4E, 0x20, 0x50, 0x4F, 0x57, 0x45, 0x52, 0x88, 0x7B, 0x05, 0x42, 0x41, 0x53, 0x45,  // 0210
  0x2E, 0x04, 0x7C, 0x1C, 0x32, 0x2E, 0x49, 0x4E, 0x53, 0x45, 0x52, 0x54, 0x20, 0x43, 0x41, 0x52,  // 0220
  0x44, 0x2F, 0x43, 0x41, 0x52, 0x54, 0x52, 0x49, 0x44, 0x47, 0x45, 0x20, 0x49, 0x4E, 0x54, 0x4F,  // 0230
  0x88, 0x7C, 0x07, 0x53, 0x59, 0x53, 0x54, 0x45, 0x4D, 0x2E, 0x04, 0x7D, 0x1C, 0x33, 0x2E, 0x54,  // 0240
  0x55, 0x52, 0x4E, 0x20, 0x50, 0x4F, 0x57, 0x45, 0x52, 0x20, 0x42, 0x41, 0x43, 0x4B, 0x20, 0x4F,  // 0250
  0x4E, 0x2C, 0x41, 0x4E, 0x44, 0x2E, 0x2E, 0x2E, 0x2E, 0x92, 0x7D, 0x0D, 0x60, 0x61, 0x62, 0x63,  // 0260
  0x64, 0x65, 0x66, 0x67, 0x68, 0x69, 0x63, 0x63, 0x63, 0xD2, 0x7D, 0x0D, 0x6A, 0x6B, 0x6C, 0x6D,  // 0270
  0x6E, 0x6F, 0x70, 0x71, 0x72, 0x00, 0x73, 0x73, 0x73, 0xDB, 0xDC, 0x21, 0x5E, 0xC7, 0x06, 0x03,  // 0280
  0x3E, 0xEB, 0xD3, 0x3E, 0x7E, 0x32, 0x00, 0xC0, 0xD3, 0x3E, 0xD9, 0xCD, 0x36, 0xC7, 0xCD, 0x31,  // 0290
  0xC7, 0xCD, 0x2C, 0xC7, 0xD9, 0x23, 0x10, 0xE8, 0xAF, 0x32, 0x00, 0xC0, 0x3E, 0xEB, 0xD3, 0x3E,  // 02A0
  0x3E, 0xE3, 0xD3, 0x3E, 0xC9, 0x21, 0xF0, 0x1F, 0x18, 0x08, 0x21, 0xF0, 0x3F, 0x18, 0x03, 0x21,  // 02B0
  0xF0, 0x7F, 0x11, 0x60, 0xC2, 0x01, 0x10, 0x00, 0xED, 0xB0, 0x21, 0x56, 0xC7, 0x11, 0x60, 0xC2,  // 02C0
  0x06, 0x08, 0x1A, 0xBE, 0xC0, 0x23, 0x13, 0x10, 0xF9, 0xCD, 0x61, 0xC7, 0xF1, 0x18, 0xCD, 0x54,  // 02D0
  0x4D, 0x52, 0x20, 0x53, 0x45, 0x47, 0x41, 0xCB, 0xAB, 0x6B, 0x11, 0x00, 0x00, 0x3A, 0x6F, 0xC2,  // 02E0
  0x4F, 0xE6, 0xF0, 0xFE, 0x40, 0x28, 0x08, 0x2A, 0x70, 0xC2, 0x23, 0x22, 0x6A, 0xC2, 0xC9, 0x79,  // 02F0
  0xD6, 0x0A, 0xE6, 0x0F, 0xF5, 0x21, 0xC4, 0xC7, 0x4F, 0x06, 0x00, 0x09, 0x46, 0x0E, 0xF0, 0x21,  // 0300
  0x00, 0x00, 0xCD, 0xB6, 0xC7, 0xED, 0x53, 0x70, 0xC2, 0xF1, 0xD6, 0x04, 0xD8, 0x4F, 0x06, 0x00,  // 0310
  0x21, 0xCD, 0xC7, 0x09, 0x46, 0x3E, 0x02, 0xC5, 0x32, 0xFF, 0xFF, 0x3C, 0xF5, 0xCD, 0xB0, 0xC7,  // 0320
  0xF1, 0xC1, 0x10, 0xF3, 0xED, 0x53, 0x70, 0xC2, 0xC9, 0x01, 0x00, 0x40, 0x21, 0x00, 0x80, 0x7B,  // 0330
  0x86, 0x5F, 0x7A, 0xCE, 0x00, 0x57, 0x23, 0x0B, 0x78, 0xB1, 0x20, 0xF3, 0xC9, 0x1F, 0x3F, 0x7F,  // 0340
  0xBF, 0x7F, 0x7F, 0x7F, 0x7F, 0x7F, 0x02, 0x06, 0x0E, 0x1E, 0x3E, 0xEB, 0xD3, 0x3E, 0x3A, 0x00,  // 0350
  0xC0, 0xD3, 0x3E, 0xC3, 0x00, 0x00, 0x11, 0x00, 0x40, 0x1B, 0x7A, 0xB3, 0x20, 0xFB, 0x10, 0xF6,  // 0360
  0xC9, 0x0E, 0x0D, 0x0C, 0x0A, 0x08, 0x06, 0xF3, 0x31, 0xF0, 0xDF, 0x21, 0x00, 0xC0, 0x11, 0x01,  // 0370
  0xC0, 0x01, 0xFF, 0x1F, 0x36, 0x00, 0xED, 0xB0, 0x21, 0xD1, 0x08, 0x0E, 0x7F, 0x06, 0x04, 0xED,  // 0380
  0xB3, 0xC3, 0x93, 0x00, 0x20, 0x00, 0xC0, 0x00, 0x3F, 0x3E, 0x3F, 0x30, 0x30, 0x38, 0x3F, 0x37,  // 0390
  0x3F, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x03, 0x30, 0x0F, 0x07, 0x16, 0x3F, 0x02, 0x00,  // 03A0
  0x0F, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xF5, 0xDB, 0xBF, 0x07, 0xD2, 0x16, 0x04, 0xC5, 0xD5,  // 03B0
  0xE5, 0xDD, 0xE5, 0xFD, 0xE5, 0x08, 0xD9, 0xF5, 0xC5, 0xD5, 0xE5, 0x3A, 0x0B, 0xC2, 0xB7, 0x28,  // 03C0
  0x0E, 0xDB, 0xDD, 0xE6, 0x10, 0x21, 0x06, 0xC2, 0x4E, 0x77, 0xA9, 0xA1, 0xC2, 0x77, 0x03, 0x3A,  // 03D0
  0x00, 0xC2, 0x0F, 0xF5, 0xDC, 0x4D, 0x00, 0xF1, 0x0F, 0xDC, 0x2F, 0x04, 0x0F, 0xF5, 0xDC, 0x77,  // 03E0
  0x05, 0xCD, 0xF0, 0x04, 0xF1, 0x0F, 0xF5, 0xDC, 0x2A, 0x0D, 0xF1, 0x0F, 0xDC, 0x5F, 0x0D, 0xCD,  // 03F0
  0xB8, 0x05, 0xAF, 0x32, 0x00, 0xC2, 0xE1, 0xD1, 0xC1, 0xF1, 0x08, 0xD9, 0xFD, 0xE1, 0xDD, 0xE1,  // 0400
  0xE1, 0xD1, 0xC1, 0xF1, 0xFB, 0xC9, 0xD5, 0xED, 0x5B, 0x25, 0xC2, 0x16, 0x88, 0xE7, 0x11, 0xFF,  // 0410
  0x8A, 0xE7, 0xD1, 0xF1, 0xFB, 0xC9, 0x21, 0x00, 0xC2, 0x77, 0x7E, 0xB7, 0x20, 0xFC, 0xC9, 0x2A,  // 0420
  0x03, 0xC2, 0x46, 0x23, 0x5E, 0x23, 0x56, 0x23, 0xE7, 0x0E, 0xBE, 0xED, 0xB3, 0xC9, 0xE7, 0xDB,  // 0430
  0xBE, 0xC9, 0xE7, 0xDB, 0xBE, 0x77, 0xE3, 0xE3, 0xDB, 0xBE, 0x23, 0x0B, 0x78, 0xB1, 0x20, 0xF3,  // 0440
  0xC9, 0x79, 0x48, 0x47, 0xC5, 0xD7, 0xEB, 0x01, 0x40, 0x00, 0x09, 0xEB, 0xC1, 0x0D, 0x20, 0xF4,  // 0450
  0xC9, 0x32, 0x01, 0xC2, 0xE7, 0x7E, 0xD9, 0x01, 0xBE, 0x04, 0x67, 0x3A, 0x01, 0xC2, 0x1F, 0x54,  // 0460
  0x38, 0x02, 0x16, 0x00, 0xED, 0x51, 0x10, 0xF6, 0xD9, 0x23, 0x0B, 0x78, 0xB1, 0x20, 0xE6, 0xC9,  // 0470
  0x36, 0x80, 0xA0, 0x81, 0xFF, 0x82, 0xFF, 0x83, 0xFF, 0x84, 0xFF, 0x85, 0xFB, 0x86, 0x00, 0x88,  // 0480
  0x00, 0x89, 0xFF, 0x8A, 0x00, 0x87, 0x10, 0xC0, 0x06, 0x04, 0xC5, 0xD5, 0xCD, 0xA5, 0x04, 0xD1,  // 0490
  0x13, 0xC1, 0x10, 0xF6, 0xC9, 0x7E, 0x23, 0xB7, 0xC8, 0x47, 0x4F, 0xCB, 0xB8, 0x7B, 0xF3, 0xD3,  // 04A0
  0xBF, 0x7A, 0xD3, 0xBF, 0x7E, 0xD3, 0xBE, 0xFB, 0xCB, 0x79, 0x28, 0x01, 0x23, 0x13, 0x13, 0x13,  // 04B0
  0x13, 0x10, 0xEA, 0x20, 0xE0, 0x23, 0x18, 0xDD, 0xAF, 0x32, 0x2A, 0xC2, 0x32, 0x26, 0xC2, 0xF3,  // 04C0
  0x21, 0x20, 0xC2, 0x7E, 0xB7, 0xC8, 0x36, 0x00, 0x3A, 0x2A, 0xC2, 0x5F, 0x16, 0x89, 0xE7, 0x3A,  // 04D0
  0x26, 0xC2, 0x5F, 0x15, 0xE7, 0xC9, 0x11, 0x00, 0x78, 0x01, 0x00, 0x07, 0x2E, 0x00, 0xEF, 0xC9,  // 04E0
  0xDB, 0xDC, 0x21, 0x07, 0xC2, 0x2F, 0x4F, 0xAE, 0x71, 0x23, 0xA1, 0x77, 0xC9, 0x3E, 0x05, 0xCD,  // 04F0
  0x26, 0x04, 0x3A, 0x02, 0xCF, 0xB7, 0x28, 0xF5, 0x11, 0x8A, 0x7B, 0x21, 0xE3, 0x0F, 0x01, 0x17,  // 0500
  0x03, 0xF3, 0xCD, 0x51, 0x04, 0xCD, 0x4D, 0x01, 0xFB, 0x3A, 0x01, 0xCF, 0xB7, 0x28, 0xFA, 0xC9,  // 0510
  0x3E, 0x03, 0x32, 0x01, 0xC2, 0x3E, 0xF0, 0x32, 0x02, 0xC2, 0x5F, 0x16, 0x88, 0xE7, 0x2E, 0xFF,  // 0520
  0x11, 0xC0, 0x5F, 0x01, 0x40, 0x00, 0xEF, 0x11, 0x00, 0xC3, 0x3E, 0x08, 0x21, 0x63, 0x05, 0x01,  // 0530
  0x04, 0x00, 0xED, 0xB0, 0x3D, 0x20, 0xF5, 0x3E, 0xD0, 0x12, 0x1E, 0x80, 0x01, 0xFF, 0x08, 0x3E,  // 0540
  0x04, 0xED, 0xA0, 0xED, 0xA0, 0x3D, 0x28, 0x04, 0x2B, 0x2B, 0x18, 0xF5, 0x10, 0xF1, 0x3E, 0x01,  // 0550
  0xC3, 0x26, 0x04, 0x38, 0x40, 0x48, 0x50, 0x47, 0xFE, 0x5A, 0xFE, 0x6C, 0xFE, 0x7E, 0xFE, 0x4F,  // 0560
  0xFF, 0x62, 0xFF, 0x74, 0xFF, 0x86, 0xFF, 0x21, 0x01, 0xC2, 0x35, 0xC0, 0x36, 0x02, 0x21, 0x02,  // 0570
  0xC2, 0x7E, 0xFE, 0x01, 0x20, 0x06, 0x3E, 0x80, 0x32, 0x00, 0xC2, 0xC9, 0x5F, 0x16, 0x88, 0xE7,  // 0580
  0x34, 0x7E, 0xED, 0x44, 0xCB, 0x7F, 0xC0, 0xFE, 0x08, 0x11, 0xE0, 0x5F, 0x38, 0x05, 0xD6, 0x08,  // 0590
  0x11, 0xC0, 0x5F, 0x21, 0xAF, 0x05, 0x06, 0x00, 0x4F, 0x09, 0x6E, 0x0E, 0x20, 0xEF, 0xC9, 0x00,  // 05A0
  0x01, 0x03, 0x07, 0x0F, 0x1F, 0x3F, 0x7F, 0xFF, 0xCD, 0xD2, 0x05, 0xDD, 0x21, 0x03, 0xCF, 0x06,  // 05B0
  0x04, 0xC5, 0xDD, 0xCB, 0x00, 0x7E, 0xC4, 0x18, 0x06, 0x11, 0x20, 0x00, 0xDD, 0x19, 0xC1, 0x10,  // 05C0
  0xF0, 0xC9, 0x3A, 0x00, 0xCF, 0xFE, 0x80, 0xDA, 0xB5, 0x08, 0xCA, 0x12, 0x06, 0x11, 0x03, 0xCF,  // 05D0
  0xD6, 0x81, 0x21, 0x87, 0x0B, 0x06, 0x00, 0x87, 0x4F, 0x09, 0x7E, 0x23, 0x66, 0x6F, 0xCD, 0xB5,  // 05E0
  0x08, 0x46, 0x23, 0xC5, 0x01, 0x09, 0x00, 0xED, 0xB0, 0x3E, 0x20, 0x12, 0x13, 0x3E, 0x01, 0x12,  // 05F0
  0x13, 0xAF, 0x12, 0x13, 0x12, 0x13, 0x12, 0xE5, 0x21, 0x12, 0x00, 0x19, 0xEB, 0xE1, 0x13, 0xC1,  // 0600
  0x10, 0xE1, 0x3E, 0x80, 0x32, 0x00, 0xCF, 0xC9, 0xDD, 0x5E, 0x0C, 0xDD, 0x56, 0x0D, 0x13, 0xDD,  // 0610
  0x73, 0x0C, 0xDD, 0x72, 0x0D, 0xDD, 0x6E, 0x0A, 0xDD, 0x66, 0x0B, 0xB7, 0xED, 0x52, 0xCC, 0x7E,  // 0620
  0x07, 0xDD, 0x5E, 0x10, 0xDD, 0x56, 0x11, 0x7B, 0xB2, 0x20, 0x07, 0xDD, 0x36, 0x16, 0x0F, 0xC3,  // 0630
  0xF0, 0x06, 0xDD, 0xCB, 0x00, 0x6E, 0x20, 0x25, 0xDD, 0x7E, 0x06, 0xB7, 0x20, 0x14, 0xDD, 0x73,  // 0640
  0x12, 0xDD, 0x72, 0x13, 0xC3, 0xA9, 0x06, 0x3D, 0x4F, 0x06, 0x00, 0x09, 0x09, 0x7E, 0x23, 0x66,  // 0650
  0x6F, 0xC9, 0x21, 0x85, 0x0B, 0xCD, 0x57, 0x06, 0xCD, 0x48, 0x07, 0x18, 0x3C, 0xD5, 0xDD, 0x6E,  // 0660
  0x14, 0xDD, 0x66, 0x15, 0xB7, 0xED, 0x52, 0xF5, 0x7D, 0xF2, 0x7E, 0x06, 0xED, 0x44, 0x67, 0xDD,  // 0670
  0x5E, 0x0C, 0xCD, 0x67, 0x09, 0xDD, 0x5E, 0x0A, 0xCD, 0x73, 0x09, 0x5F, 0x16, 0x00, 0xF1, 0x7B,  // 0680
  0xF2, 0x99, 0x06, 0xED, 0x44, 0x28, 0x02, 0x15, 0x5F, 0xE1, 0x19, 0xEB, 0xDD, 0x73, 0x12, 0xDD,  // 0690
  0x72, 0x13, 0xDD, 0x7E, 0x06, 0xB7, 0xC2, 0x62, 0x06, 0xDD, 0x7E, 0x07, 0xB7, 0x20, 0x0B, 0xDD,  // 06A0
  0x7E, 0x08, 0x2F, 0xE6, 0x0F, 0xDD, 0x77, 0x16, 0x18, 0x0B, 0xCB, 0xBF, 0x21, 0x6F, 0x0B, 0xCD,  // 06B0
  0x57, 0x06, 0xCD, 0x0E, 0x07, 0xDD, 0xCB, 0x00, 0x76, 0x20, 0x25, 0xDD, 0x7E, 0x01, 0xE6, 0x0F,  // 06C0
  0x4F, 0x06, 0x00, 0x21, 0x03, 0x07, 0x09, 0x4E, 0xDD, 0x7E, 0x12, 0xE6, 0x0F, 0xB1, 0xCD, 0xAD,  // 06D0
  0x08, 0xDD, 0x7E, 0x12, 0xE6, 0xF0, 0xDD, 0xB6, 0x13, 0x0F, 0x0F, 0x0F, 0x0F, 0xCD, 0xAD, 0x08,  // 06E0
  0xDD, 0x7E, 0x01, 0xE6, 0x0F, 0x4F, 0x06, 0x00, 0x21, 0x07, 0x07, 0x09, 0x7E, 0xDD, 0xB6, 0x16,  // 06F0
  0xC3, 0xAD, 0x08, 0x80, 0xA0, 0xC0, 0xC0, 0x90, 0xB0, 0xD0, 0xF0, 0xDD, 0x77, 0x0E, 0xE5, 0xDD,  // 0700
  0x7E, 0x0E, 0xCB, 0x3F, 0xF5, 0x4F, 0x06, 0x00, 0x09, 0xF1, 0x7E, 0xE1, 0x38, 0x14, 0x0F, 0x0F,  // 0710
  0x0F, 0x0F, 0xB7, 0x28, 0xE6, 0xFE, 0x10, 0x20, 0x05, 0xDD, 0x35, 0x0E, 0x18, 0xE0, 0xFE, 0x20,  // 0720
  0x28, 0x0B, 0xDD, 0x34, 0x0E, 0xF6, 0xF0, 0xDD, 0x86, 0x08, 0x3C, 0x38, 0x01, 0xAF, 0x2F, 0xE6,  // 0730
  0x0F, 0xDD, 0x77, 0x16, 0xC9, 0xDD, 0x77, 0x0F, 0xE5, 0xDD, 0x7E, 0x0F, 0xCB, 0x3F, 0xF5, 0x4F,  // 0740
  0x06, 0x00, 0x09, 0xF1, 0x7E, 0xE1, 0x38, 0x14, 0x0F, 0x0F, 0x0F, 0x0F, 0xB7, 0xCA, 0x45, 0x07,  // 0750
  0xFE, 0x10, 0x20, 0x08, 0xDD, 0x35, 0x0F, 0x18, 0xDF, 0xFE, 0x20, 0xC8, 0xDD, 0x34, 0x0F, 0x2F,  // 0760
  0xE6, 0x0F, 0x6F, 0x26, 0x00, 0xEB, 0x19, 0xDD, 0x75, 0x12, 0xDD, 0x74, 0x13, 0xC9, 0xDD, 0x5E,  // 0770
  0x03, 0xDD, 0x56, 0x04, 0x1A, 0x13, 0xFE, 0xE0, 0xD2, 0x12, 0x08, 0xDD, 0xCB, 0x00, 0x5E, 0x20,  // 0780
  0x60, 0xB7, 0xF2, 0xCD, 0x07, 0xD6, 0x80, 0x28, 0x03, 0xDD, 0x86, 0x05, 0x21, 0xD5, 0x08, 0x4F,  // 0790
  0x06, 0x00, 0x09, 0x09, 0x7E, 0xDD, 0x77, 0x10, 0x23, 0x7E, 0xDD, 0x77, 0x11, 0xDD, 0xCB, 0x00,  // 07A0
  0x6E, 0x28, 0x58, 0x1A, 0x13, 0xD6, 0x80, 0xDD, 0x86, 0x05, 0x21, 0xD5, 0x08, 0x4F, 0x06, 0x00,  // 07B0
  0x09, 0x09, 0x7E, 0xDD, 0x77, 0x14, 0x23, 0x7E, 0xDD, 0x77, 0x15, 0x1A, 0x13, 0xD5, 0x67, 0xDD,  // 07C0
  0x5E, 0x02, 0xCD, 0x67, 0x09, 0xD1, 0xDD, 0x75, 0x0A, 0xDD, 0x74, 0x0B, 0xAF, 0xDD, 0x77, 0x0E,  // 07D0
  0xDD, 0x77, 0x0F, 0xDD, 0x73, 0x03, 0xDD, 0x72, 0x04, 0xAF, 0xDD, 0x77, 0x0C, 0xDD, 0x77, 0x0D,  // 07E0
  0xC9, 0xDD, 0x77, 0x11, 0x1A, 0x13, 0xDD, 0x77, 0x10, 0xDD, 0xCB, 0x00, 0x6E, 0x28, 0xCC, 0x1A,  // 07F0
  0x13, 0xDD, 0x77, 0x15, 0x1A, 0x13, 0xDD, 0x77, 0x14, 0x18, 0xC0, 0x1A, 0xB7, 0xF2, 0xCC, 0x07,  // 0800
  0x18, 0xCA, 0x21, 0x25, 0x08, 0xE5, 0xE6, 0x1F, 0x21, 0x29, 0x08, 0x4F, 0x06, 0x00, 0x09, 0x09,  // 0810
  0x7E, 0x23, 0x66, 0x6F, 0xE9, 0x13, 0xC3, 0x84, 0x07, 0x8A, 0x08, 0x8F, 0x08, 0x67, 0x08, 0x7E,  // 0820
  0x08, 0x3B, 0x08, 0x49, 0x08, 0x4F, 0x08, 0x83, 0x08, 0x41, 0x08, 0xEB, 0x5E, 0x23, 0x56, 0x1B,  // 0830
  0xC9, 0x1A, 0xDD, 0x86, 0x05, 0xDD, 0x77, 0x05, 0xC9, 0xDD, 0xCB, 0x00, 0xAE, 0x1B, 0xC9, 0x1A,  // 0840
  0x13, 0xC6, 0x17, 0x4F, 0x06, 0x00, 0xDD, 0xE5, 0xE1, 0x09, 0x7E, 0xB7, 0x20, 0x02, 0x1A, 0x77,  // 0850
  0x13, 0x35, 0xC2, 0x3B, 0x08, 0x13, 0xC9, 0x1A, 0xF6, 0xE0, 0xF5, 0xCD, 0xAD, 0x08, 0xF1, 0xF6,  // 0860
  0xFC, 0x3C, 0x20, 0x05, 0xDD, 0xCB, 0x00, 0xB6, 0xC9, 0xDD, 0xCB, 0x00, 0xF6, 0xC9, 0x1A, 0xDD,  // 0870
  0x77, 0x07, 0xC9, 0x3E, 0x80, 0x32, 0x02, 0xCF, 0x1B, 0xC9, 0x1A, 0xDD, 0x77, 0x08, 0xC9, 0x3E,  // 0880
  0x80, 0x32, 0x01, 0xCF, 0xAF, 0xDD, 0x77, 0x00, 0xCD, 0x9E, 0x08, 0xE1, 0xE1, 0xC9, 0xDD, 0x7E,  // 0890
  0x01, 0xE6, 0x0F, 0x4F, 0x06, 0x00, 0x21, 0x07, 0x07, 0x09, 0x7E, 0xF6, 0x0F, 0xDD, 0xCB, 0x00,  // 08A0
  0x56, 0xC0, 0xD3, 0x7F, 0xC9, 0xD9, 0x21, 0x01, 0xCF, 0x11, 0x02, 0xCF, 0x01, 0x7F, 0x00, 0x36,  // 08B0
  0x00, 0xED, 0xB0, 0xD9, 0xD9, 0x21, 0xD1, 0x08, 0x0E, 0x7F, 0x06, 0x04, 0xED, 0xB3, 0xAF, 0xD9,  // 08C0
  0xC9, 0x9F, 0xBF, 0xDF, 0xFF, 0x00, 0x00, 0xFF, 0x03, 0xC7, 0x03, 0x90, 0x03, 0x5D, 0x03, 0x2D,  // 08D0
  0x03, 0xFF, 0x02, 0xD4, 0x02, 0xAB, 0x02, 0x85, 0x02, 0x61, 0x02, 0x3F, 0x02, 0x1E, 0x02, 0x00,  // 08E0
  0x02, 0xE3, 0x01, 0xC8, 0x01, 0xAF, 0x01, 0x96, 0x01, 0x80, 0x01, 0x6A, 0x01, 0x56, 0x01, 0x43,  // 08F0
  0x01, 0x30, 0x01, 0x1F, 0x01, 0x0F, 0x01, 0x00, 0x01, 0xF2, 0x00, 0xE4, 0x00, 0xD7, 0x00, 0xCB,  // 0900
  0x00, 0xC0, 0x00, 0xB5, 0x00, 0xAB, 0x00, 0xA1, 0x00, 0x98, 0x00, 0x90, 0x00, 0x88, 0x00, 0x80,  // 0910
  0x00, 0x79, 0x00, 0x72, 0x00, 0x6C, 0x00, 0x66, 0x00, 0x60, 0x00, 0x5B, 0x00, 0x55, 0x00, 0x51,  // 0920
  0x00, 0x4C, 0x00, 0x48, 0x00, 0x44, 0x00, 0x40, 0x00, 0x3C, 0x00, 0x39, 0x00, 0x36, 0x00, 0x33,  // 0930
  0x00, 0x30, 0x00, 0x2D, 0x00, 0x2B, 0x00, 0x28, 0x00, 0x26, 0x00, 0x24, 0x00, 0x22, 0x00, 0x20,  // 0940
  0x00, 0x1E, 0x00, 0x1C, 0x00, 0x1B, 0x00, 0x19, 0x00, 0x18, 0x00, 0x16, 0x00, 0x15, 0x00, 0x14,  // 0950
  0x00, 0x13, 0x00, 0x12, 0x00, 0x11, 0x00, 0x16, 0x00, 0x6A, 0x06, 0x08, 0x29, 0x30, 0x01, 0x19,  // 0960
  0x10, 0xFA, 0xC9, 0x06, 0x08, 0xED, 0x6A, 0x7C, 0x38, 0x03, 0xBB, 0x38, 0x03, 0x93, 0x67, 0xB7,  // 0970
  0x10, 0xF3, 0x7D, 0x17, 0x2F, 0xC9, 0x04, 0xA0, 0x20, 0x05, 0xC7, 0x09, 0x05, 0x01, 0x04, 0x0D,  // 0980
  0xA0, 0x21, 0x05, 0xBB, 0x09, 0x05, 0x01, 0x04, 0x0D, 0xA0, 0x22, 0x05, 0xD2, 0x09, 0x05, 0x01,  // 0990
  0x04, 0x0D, 0x80, 0x23, 0x05, 0xAB, 0x09, 0x00, 0x00, 0x00, 0x00, 0x80, 0x10, 0xE2, 0x04, 0xE3,  // 09A0
  0x01, 0xE0, 0x0D, 0x8D, 0x08, 0xE3, 0x02, 0xE0, 0x0F, 0x1C, 0xE1, 0x81, 0xA5, 0x08, 0xE5, 0x80,  // 09B0
  0xE7, 0x8D, 0x81, 0x10, 0x80, 0x0C, 0xE1, 0x85, 0xA9, 0x08, 0xE5, 0x80, 0x8A, 0x8A, 0x10, 0x80,  // 09C0
  0x08, 0xE1, 0x88, 0xAC, 0x08, 0xE5, 0x80, 0x86, 0x86, 0x10, 0x80, 0x08, 0xE1, 0x04, 0x80, 0x20,  // 09D0
  0x05, 0x02, 0x0A, 0x00, 0x01, 0x02, 0x0E, 0x80, 0x21, 0x05, 0x14, 0x0A, 0x00, 0x01, 0x02, 0x0F,  // 09E0
  0x80, 0x22, 0x05, 0x27, 0x0A, 0x00, 0x01, 0x02, 0x0E, 0x80, 0x23, 0x05, 0x3A, 0x0A, 0x00, 0x00,  // 09F0
  0x00, 0x00, 0x8F, 0x02, 0x02, 0x02, 0xE3, 0x04, 0x0F, 0xE3, 0x02, 0x8D, 0x03, 0x03, 0x8F, 0xE3,  // 0A00
  0x04, 0x91, 0x18, 0xE1, 0x9F, 0x02, 0x02, 0x02, 0xE3, 0x04, 0xA0, 0x0F, 0xE3, 0x02, 0x9D, 0x03,  // 0A10
  0x03, 0x9F, 0xE3, 0x04, 0xA1, 0x18, 0xE1, 0xA2, 0x02, 0x02, 0x02, 0xE3, 0x04, 0xA4, 0x0F, 0xE3,  // 0A20
  0x02, 0xA0, 0x03, 0x03, 0xA2, 0xE3, 0x04, 0xA4, 0x18, 0xE1, 0xE2, 0x04, 0xE3, 0x01, 0xE0, 0x0D,  // 0A30
  0x8D, 0x02, 0x02, 0x02, 0xE3, 0x02, 0xE0, 0x0F, 0x0F, 0xE3, 0x01, 0xE0, 0x0D, 0x03, 0x03, 0x03,  // 0A40
  0xE3, 0x02, 0xE0, 0x0F, 0x18, 0xE1, 0x04, 0x80, 0x20, 0x02, 0x7B, 0x0A, 0x00, 0x01, 0x03, 0x0B,  // 0A50
  0x80, 0x21, 0x02, 0x7D, 0x0A, 0x00, 0x01, 0x03, 0x0C, 0x80, 0x22, 0x02, 0xA2, 0x0A, 0x00, 0x01,  // 0A60
  0x03, 0x0B, 0x80, 0x23, 0x02, 0xC7, 0x0A, 0x00, 0x00, 0x00, 0x00, 0x80, 0x01, 0x99, 0x08, 0xA0,  // 0A70
  0x9D, 0xA0, 0x9E, 0x9B, 0x9D, 0x9B, 0x99, 0x9B, 0x9D, 0x9B, 0x94, 0x96, 0x94, 0x80, 0x99, 0x08,  // 0A80
  0xA0, 0x9D, 0xA0, 0x9E, 0x9B, 0x9D, 0x9B, 0x9D, 0x9B, 0x99, 0x98, 0x99, 0x99, 0x99, 0x80, 0xE4,  // 0A90
  0x7D, 0x0A, 0x8D, 0x08, 0x99, 0x8D, 0x99, 0x92, 0x9E, 0x94, 0xA0, 0x8D, 0x94, 0x8D, 0x99, 0x88,  // 0AA0
  0x8F, 0x88, 0x94, 0x8D, 0x08, 0x99, 0x8D, 0x99, 0x92, 0x9E, 0x94, 0xA0, 0x8D, 0x94, 0x88, 0x94,  // 0AB0
  0x8D, 0x99, 0x8D, 0x80, 0xE4, 0xA2, 0x0A, 0xE2, 0x04, 0xE3, 0x01, 0xE0, 0x0D, 0x8D, 0x08, 0xE3,  // 0AC0
  0x02, 0xE0, 0x0F, 0x08, 0xE3, 0x01, 0xE0, 0x0D, 0x04, 0x04, 0xE3, 0x02, 0xE0, 0x0F, 0x08, 0xE4,  // 0AD0
  0xC9, 0x0A, 0x04, 0x80, 0x20, 0x04, 0x07, 0x0B, 0x00, 0x01, 0x02, 0x0E, 0x80, 0x21, 0x04, 0x13,  // 0AE0
  0x0B, 0x00, 0x01, 0x02, 0x0D, 0x80, 0x22, 0x04, 0x1F, 0x0B, 0x00, 0x01, 0x02, 0x0E, 0x80, 0x23,  // 0AF0
  0x04, 0x2B, 0x0B, 0x00, 0x00, 0x00, 0x00, 0x9D, 0x02, 0x9B, 0x9D, 0xA0, 0x9D, 0xA0, 0xE3, 0x04,  // 0B00
  0xA5, 0x10, 0xE1, 0x99, 0x02, 0x98, 0x99, 0x9D, 0x99, 0x9D, 0xE3, 0x04, 0xA2, 0x10, 0xE1, 0x8D,  // 0B10
  0x02, 0x02, 0x02, 0x88, 0x88, 0x88, 0xE3, 0x04, 0x91, 0x10, 0xE1, 0xE2, 0x04, 0xE3, 0x01, 0xE0,  // 0B20
  0x0D, 0x8D, 0x04, 0xE3, 0x02, 0xE0, 0x0F, 0x04, 0xE3, 0x01, 0xE0, 0x0D, 0x02, 0x02, 0xE3, 0x02,  // 0B30
  0xE0, 0x0F, 0x10, 0xE1, 0xAF, 0xEC, 0xEE, 0x01, 0xBC, 0xDD, 0xEE, 0xFF, 0xEE, 0xFF, 0xDD, 0xCC,  // 0B40
  0xBB, 0xDD, 0xEE, 0xFF, 0xEE, 0xDD, 0xCC, 0xBB, 0xCC, 0xDD, 0xEE, 0xFF, 0xFE, 0xDC, 0xBC, 0xDE,  // 0B50
  0xFE, 0xDB, 0xAB, 0xCD, 0xEF, 0xED, 0xCB, 0xAB, 0xCD, 0xEF, 0xEE, 0x01, 0xFF, 0xEE, 0x00, 0x77,  // 0B60
  0x0B, 0x79, 0x0B, 0x80, 0x0B, 0x44, 0x0B, 0xFF, 0x02, 0xFF, 0xED, 0xDC, 0xCB, 0xBA, 0xA9, 0x02,  // 0B70
  0xEF, 0xFF, 0xFF, 0xEE, 0x02, 0x48, 0x0B, 0x86, 0x09, 0xDD, 0x09, 0x56, 0x0A, 0xE2, 0x0A, 0xFF,  // 0B80
  0x3E, 0xFF, 0x32, 0x0B, 0xC2, 0x21, 0x93, 0x0D, 0x11, 0x30, 0xC2, 0x01, 0x04, 0x00, 0xED, 0xB0,  // 0B90
  0x21, 0xC2, 0xC9, 0x06, 0x1E, 0x36, 0x03, 0x23, 0x23, 0x10, 0xFA, 0xF3, 0x21, 0x9E, 0x0D, 0x11,  // 0BA0
  0x64, 0x79, 0x06, 0x0A, 0xD7, 0xF3, 0x21, 0x30, 0xC2, 0x11, 0x6A, 0x79, 0xCD, 0x76, 0x0D, 0xFB,  // 0BB0
  0x3E, 0x10, 0xCD, 0x26, 0x04, 0xDD, 0x21, 0x00, 0xC4, 0xCD, 0x27, 0x0F, 0xDD, 0x36, 0x07, 0x08,  // 0BC0
  0xDD, 0x36, 0x0C, 0x0D, 0xDD, 0x36, 0x04, 0x04, 0xDD, 0x21, 0x40, 0xC4, 0xCD, 0x27, 0x0F, 0xDD,  // 0BD0
  0x21, 0x20, 0xC4, 0xCD, 0x27, 0x0F, 0xCD, 0xC1, 0x0C, 0x3E, 0x01, 0x32, 0x00, 0xC4, 0x3C, 0x32,  // 0BE0
  0x40, 0xC4, 0x3C, 0x32, 0x20, 0xC4, 0xCD, 0x99, 0x0E, 0x01, 0x01, 0x14, 0xCD, 0xBA, 0x0C, 0x3E,  // 0BF0
  0x83, 0x32, 0x00, 0xCF, 0x3E, 0x11, 0xCD, 0x26, 0x04, 0xCD, 0x99, 0x0E, 0x21, 0x34, 0xC2, 0x7E,  // 0C00
  0xB7, 0x20, 0x38, 0x23, 0x7E, 0xB7, 0x28, 0xEC, 0xF3, 0x21, 0x97, 0x0D, 0x11, 0xDA, 0x79, 0x06,  // 0C10
  0x07, 0xD7, 0xFB, 0x06, 0x00, 0xC5, 0x01, 0x80, 0x01, 0xCD, 0xBA, 0x0C, 0x11, 0xDB, 0x79, 0x21,  // 0C20
  0x74, 0xC2, 0x34, 0xF3, 0xE7, 0x06, 0x07, 0x3A, 0x74, 0xC2, 0xE6, 0x08, 0xD3, 0xBE, 0xF5, 0xF1,  // 0C30
  0xDB, 0xBE, 0x10, 0xF3, 0xFB, 0xC1, 0x10, 0xDD, 0xC3, 0x77, 0x03, 0x36, 0x00, 0x3E, 0x84, 0x32,  // 0C40
  0x00, 0xCF, 0x01, 0x01, 0x60, 0xCD, 0xBA, 0x0C, 0x3E, 0xD0, 0x32, 0x00, 0xC3, 0x01, 0x01, 0x30,  // 0C50
  0xCD, 0xBA, 0x0C, 0x21, 0x30, 0xC2, 0x7E, 0xC6, 0x01, 0x27, 0x77, 0x23, 0x34, 0x7E, 0xFE, 0x0D,  // 0C60
  0x30, 0x19, 0x5F, 0x16, 0x00, 0x21, 0xA6, 0x0D, 0x19, 0x7E, 0x2A, 0x32, 0xC2, 0x84, 0x27, 0x30,  // 0C70
  0x02, 0x3E, 0x99, 0x67, 0x6A, 0x22, 0x32, 0xC2, 0xC3, 0xB5, 0x0B, 0x3E, 0x82, 0x32, 0x00, 0xCF,  // 0C80
  0x21, 0xAA, 0x0C, 0x11, 0xD0, 0x79, 0x06, 0x10, 0xF3, 0xD7, 0xFB, 0x01, 0x80, 0x00, 0xCD, 0xBA,  // 0C90
  0x0C, 0x01, 0x80, 0x00, 0xCD, 0xBA, 0x0C, 0xC3, 0x77, 0x03, 0x43, 0x4F, 0x4E, 0x47, 0x52, 0x41,  // 0CA0
  0x54, 0x55, 0x4C, 0x41, 0x54, 0x49, 0x4F, 0x4E, 0x53, 0x21, 0x79, 0xCD, 0x26, 0x04, 0x10, 0xFA,  // 0CB0
  0xC9, 0x3A, 0x31, 0xC2, 0x3D, 0x57, 0x87, 0x82, 0x5F, 0xAF, 0xCB, 0x1A, 0x1F, 0x83, 0x5F, 0x21,  // 0CC0
  0xB1, 0x19, 0x19, 0x7E, 0x32, 0x08, 0xC4, 0x23, 0x7E, 0x32, 0x48, 0xC4, 0x23, 0x7E, 0x32, 0x47,  // 0CD0
  0xC4, 0x23, 0x11, 0x00, 0xCA, 0x06, 0x80, 0xC5, 0x06, 0x04, 0x4E, 0x79, 0x3C, 0xE6, 0x03, 0xC6,  // 0CE0
  0x04, 0x12, 0x13, 0xAF, 0x12, 0x13, 0xCB, 0x19, 0xCB, 0x19, 0x10, 0xEF, 0x23, 0xC1, 0x10, 0xE7,  // 0CF0
  0x21, 0x3E, 0xCA, 0x01, 0x74, 0x10, 0x11, 0x40, 0x00, 0x71, 0x19, 0x10, 0xFC, 0x3E, 0xFF, 0x32,  // 0D00
  0x44, 0xC2, 0x11, 0x36, 0x80, 0xE7, 0x3E, 0x08, 0xCD, 0x26, 0x04, 0x3A, 0x44, 0xC2, 0xB7, 0x20,  // 0D10
  0xF5, 0x11, 0x06, 0x80, 0xE7, 0x11, 0xFF, 0x8A, 0xE7, 0xC9, 0x11, 0x00, 0x88, 0xE7, 0x11, 0x37,  // 0D20
  0x8A, 0xE7, 0x21, 0x25, 0xC2, 0x7E, 0x35, 0x20, 0x05, 0xAF, 0x32, 0x44, 0xC2, 0xC9, 0xED, 0x44,  // 0D30
  0x5F, 0xE6, 0x07, 0xC0, 0x7B, 0x0F, 0x0F, 0xC6, 0xC0, 0x5F, 0x16, 0x79, 0x6F, 0x26, 0xC9, 0x06,  // 0D40
  0x11, 0xC5, 0x7E, 0xCF, 0x01, 0x40, 0x00, 0x09, 0xEB, 0x09, 0xEB, 0xC1, 0x10, 0xF3, 0xC9, 0x21,  // 0D50
  0x32, 0xC2, 0x35, 0xF0, 0x36, 0x3B, 0x23, 0x7E, 0xD6, 0x01, 0x27, 0x77, 0x11, 0x7A, 0x79, 0x20,  // 0D60
  0x05, 0x3D, 0x32, 0x35, 0xC2, 0x3C, 0xE7, 0x7E, 0x1F, 0x1F, 0x1F, 0x1F, 0xE6, 0x0F, 0x28, 0x02,  // 0D70
  0xF6, 0x30, 0xCD, 0x8A, 0x0D, 0x7E, 0xE6, 0x0F, 0xF6, 0x30, 0xD3, 0xBE, 0xF5, 0xF1, 0x3E, 0x08,  // 0D80
  0xD3, 0xBE, 0xC9, 0x01, 0x01, 0x00, 0x61, 0x54, 0x49, 0x4D, 0x45, 0x20, 0x55, 0x50, 0x52, 0x44,  // 0D90
  0x20, 0x20, 0x20, 0x20, 0x54, 0x49, 0x4D, 0x45, 0x30, 0x35, 0x25, 0x35, 0x35, 0x30, 0x35, 0x35,  // 0DA0
  0x35, 0x10, 0x15, 0xB9, 0x0D, 0x43, 0x0E, 0x6F, 0x0E, 0xDD, 0xCB, 0x01, 0x7E, 0x28, 0x15, 0xDD,  // 0DB0
  0x35, 0x1F, 0x28, 0x06, 0x2A, 0x05, 0xC4, 0xC3, 0x85, 0x0F, 0xDD, 0xCB, 0x01, 0xBE, 0x21, 0x00,  // 0DC0
  0x00, 0x22, 0x09, 0xC4, 0xCD, 0x2C, 0x0E, 0x3A, 0x07, 0xC2, 0x0F, 0xDC, 0xF3, 0x0D, 0x0F, 0xDC,  // 0DD0
  0x05, 0x0E, 0x0F, 0x38, 0x39, 0x0F, 0xD0, 0xCB, 0x4E, 0xC0, 0xDD, 0x36, 0x09, 0x01, 0x21, 0x8D,  // 0DE0
  0x0E, 0x18, 0x1D, 0xE5, 0x11, 0xC0, 0xFF, 0x19, 0xCB, 0x46, 0xE1, 0xC0, 0xDD, 0x36, 0x0A, 0xFF,  // 0DF0
  0x21, 0x96, 0x0E, 0x18, 0x0A, 0xCB, 0x46, 0xC0, 0xDD, 0x36, 0x0A, 0x01, 0x21, 0x93, 0x0E, 0xF1,  // 0E00
  0x22, 0x05, 0xC4, 0xDD, 0x36, 0x1F, 0x08, 0xDD, 0xCB, 0x01, 0xFE, 0xC3, 0x85, 0x0F, 0x2B, 0x2B,  // 0E10
  0xCB, 0x4E, 0xC0, 0xDD, 0x36, 0x09, 0xFF, 0x21, 0x90, 0x0E, 0x18, 0xE4, 0x3A, 0x07, 0xC4, 0x0F,  // 0E20
  0x0F, 0xE6, 0x3E, 0x5F, 0x3A, 0x08, 0xC4, 0xE6, 0xF8, 0x6F, 0x26, 0x00, 0x29, 0x29, 0x29, 0x16,  // 0E30
  0xC8, 0x19, 0xC9, 0xDD, 0xCB, 0x01, 0x46, 0x28, 0x19, 0x2A, 0x07, 0xC4, 0x7D, 0xDD, 0xBE, 0x07,  // 0E40
  0x20, 0x0A, 0x7C, 0xDD, 0xBE, 0x08, 0x20, 0x04, 0x32, 0x34, 0xC2, 0xC9, 0x21, 0x87, 0x0E, 0xC3,  // 0E50
  0x85, 0x0F, 0xDD, 0x36, 0x0C, 0x0C, 0xDD, 0xCB, 0x01, 0xC6, 0xDD, 0x36, 0x04, 0x1E, 0xC9, 0xDD,  // 0E60
  0xCB, 0x01, 0x46, 0x28, 0x06, 0x21, 0x8A, 0x0E, 0xC3, 0x85, 0x0F, 0x2A, 0x07, 0xC4, 0x22, 0x27,  // 0E70
  0xC4, 0xDD, 0x36, 0x0C, 0x53, 0x18, 0xDF, 0x02, 0x47, 0x0C, 0x02, 0x20, 0x53, 0x02, 0x0D, 0x0E,  // 0E80
  0x02, 0x0F, 0x10, 0x02, 0x11, 0x12, 0x02, 0x13, 0x14, 0x21, 0x00, 0xC3, 0x22, 0x09, 0xC2, 0xDD,  // 0E90
  0x21, 0x00, 0xC4, 0x06, 0x04, 0xDD, 0x7E, 0x00, 0xE6, 0x7F, 0xCA, 0xC5, 0x0E, 0xC5, 0x21, 0xB1,  // 0EA0
  0x0D, 0xCD, 0xB1, 0x0F, 0xDD, 0x7E, 0x00, 0xB7, 0xCA, 0xC4, 0x0E, 0xCD, 0x6D, 0x0F, 0xCD, 0x1D,  // 0EB0
  0x0F, 0xCD, 0xD2, 0x0E, 0xC1, 0x11, 0x20, 0x00, 0xDD, 0x19, 0x10, 0xD9, 0x2A, 0x09, 0xC2, 0x36,  // 0EC0
  0xD0, 0xC9, 0xDD, 0x7E, 0x00, 0xB7, 0xC8, 0xDD, 0x7E, 0x08, 0xFE, 0xC0, 0xD0, 0x2A, 0x09, 0xC2,  // 0ED0
  0x77, 0x23, 0x08, 0xDD, 0x7E, 0x0C, 0xFE, 0x0C, 0x28, 0x12, 0x22, 0x09, 0xC2, 0x2B, 0xCB, 0x25,  // 0EE0
  0xCB, 0xFD, 0xDD, 0x7E, 0x07, 0x77, 0x23, 0xDD, 0x7E, 0x0C, 0x77, 0xC9, 0x08, 0x06, 0x04, 0xE5,  // 0EF0
  0xD6, 0x08, 0x77, 0x23, 0x10, 0xFA, 0x22, 0x09, 0xC2, 0xE1, 0x2B, 0xCB, 0x25, 0xCB, 0xFD, 0x06,  // 0F00
  0x05, 0xDD, 0x4E, 0x07, 0x08, 0x71, 0x23, 0x77, 0x23, 0x3D, 0x10, 0xF9, 0xC9, 0xDD, 0x7E, 0x0A,  // 0F10
  0xDD, 0x86, 0x08, 0xDD, 0x77, 0x08, 0xC9, 0xAF, 0xDD, 0xE5, 0xE1, 0x77, 0x2C, 0x77, 0x2C, 0x77,  // 0F20
  0x2C, 0x36, 0x01, 0x2C, 0x77, 0x2C, 0x77, 0x2C, 0x77, 0x2C, 0x77, 0x2C, 0x77, 0x2C, 0x77, 0x2C,  // 0F30
  0x77, 0x2C, 0x77, 0x2C, 0x77, 0x2C, 0x77, 0x2C, 0x77, 0x2C, 0x77, 0x2C, 0x77, 0x2C, 0x77, 0x2C,  // 0F40
  0x77, 0x2C, 0x77, 0x2C, 0x77, 0x2C, 0x77, 0x2C, 0x77, 0x2C, 0x77, 0x2C, 0x77, 0x2C, 0x77, 0x2C,  // 0F50
  0x77, 0x2C, 0x77, 0x2C, 0x77, 0x2C, 0x77, 0x2C, 0x77, 0x2C, 0x77, 0x4F, 0xC9, 0x3A, 0x28, 0xC2,  // 0F60
  0xDD, 0x56, 0x09, 0x82, 0x57, 0xDD, 0x86, 0x07, 0xDD, 0x77, 0x07, 0xCB, 0x7A, 0x20, 0x03, 0x38,  // 0F70
  0xA6, 0xC9, 0x30, 0xA3, 0xC9, 0x46, 0x23, 0x50, 0xDD, 0x35, 0x03, 0xDD, 0x7E, 0x02, 0x20, 0x0E,  // 0F80
  0xDD, 0x5E, 0x04, 0xDD, 0x73, 0x03, 0x3C, 0xBA, 0x38, 0x01, 0xAF, 0xDD, 0x77, 0x02, 0x4F, 0x06,  // 0F90
  0x00, 0x09, 0x7E, 0xDD, 0x77, 0x0C, 0xC9, 0x46, 0x23, 0x50, 0xDD, 0x7E, 0x02, 0x18, 0xEF, 0xE6,  // 0FA0
  0x0F, 0x87, 0x5F, 0x16, 0x00, 0x19, 0x7E, 0x23, 0x66, 0x6F, 0xE9, 0x76, 0x77, 0x78, 0x79, 0x7A,  // 0FB0
  0x7B, 0x7C, 0x7D, 0x7E, 0x7F, 0x80, 0x81, 0x82, 0x83, 0x84, 0x85, 0x86, 0x87, 0x88, 0x89, 0x8A,  // 0FC0
  0x8B, 0x8C, 0x8D, 0x8E, 0x8F, 0x90, 0x91, 0x92, 0x93, 0x94, 0x95, 0x96, 0x94, 0x97, 0x98, 0x94,  // 0FD0
  0x94, 0x94, 0x99, 0x9A, 0x9B, 0x9C, 0x9D, 0x9E, 0x9F, 0xA0, 0xA1, 0xA2, 0xA3, 0xA4, 0x00, 0xA5,  // 0FE0
  0xA6, 0xA7, 0xA8, 0x9F, 0xA0, 0xA1, 0xA2, 0xA9, 0xAA, 0xAB, 0xAC, 0xAD, 0xAE, 0xAF, 0xB0, 0xB1,  // 0FF0
  0xB2, 0xB3, 0xB4, 0xB5, 0xB6, 0x00, 0xB7, 0xB8, 0xB9, 0xB0, 0xB1, 0xB2, 0xB3, 0xB4, 0xBA, 0xBB,  // 1000
  0xBC, 0xBD, 0xBE, 0xBF, 0xC0, 0xC1, 0xC2, 0xC3, 0xC4, 0xC5, 0xC6, 0xC7, 0xC8, 0xC9, 0xCA, 0xCB,  // 1010
  0xCC, 0xC2, 0xC3, 0xC4, 0xC5, 0xCD, 0xCE, 0xCF, 0x89, 0x07, 0x1C, 0x30, 0x60, 0x41, 0xC6, 0x84,  // 1020
  0x88, 0xFF, 0x03, 0x00, 0x81, 0xFF, 0x03, 0x00, 0x89, 0xE1, 0x27, 0x2C, 0x38, 0xF0, 0x31, 0x21,  // 1030
  0x22, 0xFF, 0x03, 0x00, 0x95, 0x7F, 0x80, 0x00, 0x00, 0xF8, 0x09, 0x0B, 0x0E, 0xFC, 0x0C, 0x08,  // 1040
  0x08, 0x7F, 0xC0, 0x00, 0x00, 0x1F, 0x60, 0x40, 0x80, 0xFE, 0x03, 0x02, 0x81, 0xFE, 0x03, 0x02,  // 1050
  0xA8, 0x03, 0x0E, 0x08, 0x18, 0x11, 0x31, 0x22, 0x22, 0xE0, 0x39, 0x0F, 0x0E, 0xC6, 0x46, 0x22,  // 1060
  0x23, 0xFC, 0x86, 0x7B, 0x8D, 0xB5, 0x8D, 0xB5, 0x7B, 0x88, 0x88, 0x84, 0xC6, 0x41, 0x60, 0x30,  // 1070
  0x1C, 0xFF, 0x07, 0x01, 0x00, 0xF0, 0x0C, 0x04, 0x02, 0x04, 0xE2, 0x85, 0x63, 0x62, 0x22, 0x22,  // 1080
  0x3F, 0x03, 0x00, 0x81, 0xFF, 0x03, 0x00, 0x81, 0xF8, 0x03, 0x18, 0x81, 0xF8, 0x03, 0x18, 0x81,  // 1090
  0x8F, 0x03, 0x88, 0x81, 0x8F, 0x03, 0x88, 0x81, 0xFE, 0x03, 0x02, 0x88, 0xE2, 0x22, 0x23, 0x23,  // 10A0
  0x62, 0x44, 0x44, 0xC4, 0x03, 0x88, 0x82, 0x11, 0x23, 0x03, 0x11, 0x03, 0x88, 0x84, 0xC4, 0x86,  // 10B0
  0xFC, 0x00, 0x03, 0x80, 0x83, 0xC0, 0x40, 0xFF, 0x03, 0x80, 0x81, 0xFF, 0x03, 0x80, 0x95, 0xE2,  // 10C0
  0x02, 0x04, 0x0C, 0xF0, 0x00, 0x01, 0x07, 0x22, 0x22, 0x21, 0x71, 0x70, 0xD8, 0x8C, 0x07, 0x3F,  // 10D0
  0x00, 0x00, 0x80, 0x7F, 0x03, 0x00, 0x90, 0xF8, 0x08, 0x08, 0x0C, 0xFC, 0x0E, 0x0B, 0x09, 0x8E,  // 10E0
  0x80, 0x40, 0x60, 0x1F, 0x00, 0x00, 0xC0, 0x02, 0x23, 0x02, 0x22, 0x81, 0xE2, 0x03, 0x00, 0x85,  // 10F0
  0x11, 0x10, 0x22, 0x22, 0x23, 0x03, 0x46, 0x85, 0xC4, 0x04, 0x02, 0x02, 0xFE, 0x03, 0x00, 0x85,  // 1100
  0x40, 0x60, 0x20, 0x20, 0x30, 0x03, 0x10, 0x81, 0xFF, 0x07, 0x00, 0x81, 0xFC, 0x07, 0x00, 0x81,  // 1110
  0x01, 0x07, 0x00, 0x81, 0xF8, 0x07, 0x00, 0x81, 0x7F, 0x07, 0x00, 0x81, 0xF0, 0x07, 0x00, 0x81,  // 1120
  0x7C, 0x04, 0x3C, 0x02, 0x3E, 0x82, 0x36, 0x1F, 0x04, 0x1E, 0x02, 0x3E, 0x81, 0x2E, 0x03, 0x01,  // 1130
  0x03, 0x03, 0x02, 0x06, 0x03, 0xE0, 0x02, 0x70, 0x96, 0x78, 0x38, 0x38, 0x03, 0x0F, 0x1C, 0x18,  // 1140
  0x38, 0x38, 0x3C, 0x3F, 0x90, 0xF1, 0x31, 0x1B, 0x0A, 0x08, 0x00, 0x80, 0xFF, 0xFF, 0xDD, 0x05,  // 1150
  0x1C, 0x85, 0x87, 0xC3, 0xC3, 0x63, 0x23, 0x03, 0x03, 0x02, 0xFF, 0x82, 0x83, 0x81, 0x02, 0x80,  // 1160
  0x02, 0x84, 0x82, 0x1F, 0x0F, 0x03, 0x8E, 0x03, 0x0E, 0x84, 0xF0, 0xF8, 0x3C, 0x0C, 0x03, 0x0E,  // 1170
  0x8D, 0x0C, 0x07, 0x1F, 0x38, 0x30, 0x70, 0x70, 0x78, 0x7F, 0x27, 0xE3, 0x61, 0x31, 0x02, 0x10,  // 1180
  0x02, 0x00, 0x82, 0xC3, 0x81, 0x02, 0xC3, 0x02, 0xE6, 0x02, 0x7C, 0x8A, 0xC3, 0x8F, 0x1C, 0x18,  // 1190
  0x38, 0x38, 0x3C, 0x3F, 0x1F, 0x0F, 0x03, 0x8F, 0x02, 0x0F, 0x81, 0x0D, 0x05, 0x07, 0x02, 0x8F,  // 11A0
  0x82, 0x8B, 0xC0, 0x07, 0x80, 0x81, 0x36, 0x02, 0x37, 0x04, 0x33, 0x85, 0x31, 0x2E, 0x6E, 0x6E,  // 11B0
  0x4E, 0x03, 0xCE, 0x9D, 0x8E, 0x06, 0x06, 0x0C, 0x0F, 0x0F, 0x0C, 0x18, 0x18, 0x38, 0x3C, 0x1C,  // 11C0
  0xFC, 0xFC, 0x1E, 0x0E, 0x0E, 0x1F, 0x0F, 0x03, 0x00, 0x20, 0x20, 0x30, 0x18, 0xE0, 0xF0, 0xF0,  // 11D0
  0x78, 0x03, 0x38, 0x81, 0x70, 0x08, 0x1C, 0x08, 0x03, 0x02, 0xFC, 0x02, 0x84, 0x02, 0x80, 0x83,  // 11E0
  0x81, 0x83, 0x0E, 0x02, 0x0F, 0x02, 0x0E, 0x86, 0xCE, 0x8E, 0x8E, 0x3C, 0xF8, 0xF0, 0x02, 0x38,  // 11F0
  0x02, 0x1C, 0x8D, 0x0E, 0x3F, 0x1F, 0x07, 0x00, 0x40, 0x40, 0x60, 0x30, 0xC0, 0xE0, 0xE0, 0xF0,  // 1200
  0x03, 0x70, 0x81, 0xE0, 0x08, 0x38, 0x03, 0x0D, 0x02, 0x0C, 0x87, 0xCC, 0x8C, 0x8C, 0x8B, 0xDB,  // 1210
  0xDB, 0xD3, 0x03, 0xF3, 0x81, 0x63, 0x08, 0x80, 0x82, 0x31, 0x79, 0x06, 0x00, 0x82, 0x8E, 0x9F,  // 1220
  0x06, 0x00, 0x82, 0x18, 0x3C, 0x06, 0x00, 0x82, 0x0E, 0x1F, 0x06, 0x00, 0x82, 0x1F, 0x13, 0x06,  // 1230
  0x00, 0x82, 0xE0, 0xC0, 0x06, 0x00, 0x82, 0x1C, 0x3E, 0x06, 0x00, 0x82, 0x03, 0x07, 0x06, 0x00,  // 1240
  0x02, 0xFF, 0x06, 0x00, 0x82, 0x0E, 0x1F, 0x06, 0x00, 0x82, 0x0E, 0x07, 0x0E, 0x00, 0x82, 0x3F,  // 1250
  0x27, 0x06, 0x00, 0x82, 0xC0, 0x80, 0x06, 0x00, 0x82, 0x38, 0xFE, 0x06, 0x00, 0x82, 0x1F, 0x13,  // 1260
  0x06, 0x00, 0x82, 0x0C, 0x1E, 0x06, 0x00, 0x82, 0x63, 0x67, 0x06, 0x00, 0x82, 0x80, 0xC0, 0x06,  // 1270
  0x00, 0x00, 0x89, 0x07, 0x1C, 0x30, 0x60, 0x41, 0xC6, 0x84, 0x88, 0xFF, 0x03, 0x00, 0x81, 0xFF,  // 1280
  0x03, 0x00, 0x89, 0xE1, 0x27, 0x2C, 0x38, 0xF0, 0x31, 0x21, 0x22, 0xFF, 0x03, 0x00, 0x95, 0x7F,  // 1290
  0x80, 0x00, 0x00, 0xF8, 0x09, 0x0B, 0x0E, 0xFC, 0x0C, 0x08, 0x08, 0x7F, 0xC0, 0x00, 0x00, 0x1F,  // 12A0
  0x60, 0x40, 0x80, 0xFE, 0x03, 0x02, 0x81, 0xFE, 0x03, 0x02, 0xA8, 0x03, 0x0E, 0x08, 0x18, 0x11,  // 12B0
  0x31, 0x22, 0x22, 0xE0, 0x39, 0x0F, 0x0E, 0xC6, 0x46, 0x22, 0x23, 0xFC, 0x86, 0x7B, 0x8D, 0xB5,  // 12C0
  0x8D, 0xB5, 0x7B, 0x88, 0x88, 0x84, 0xC6, 0x41, 0x60, 0x30, 0x1C, 0xFF, 0x07, 0x01, 0x00, 0xF0,  // 12D0
  0x0C, 0x04, 0x02, 0x04, 0xE2, 0x85, 0x63, 0x62, 0x22, 0x22, 0x3F, 0x03, 0x00, 0x81, 0xFF, 0x03,  // 12E0
  0x00, 0x81, 0xF8, 0x03, 0x18, 0x81, 0xF8, 0x03, 0x18, 0x81, 0x8F, 0x03, 0x88, 0x81, 0x8F, 0x03,  // 12F0
  0x88, 0x81, 0xFE, 0x03, 0x02, 0x88, 0xE2, 0x22, 0x23, 0x23, 0x62, 0x44, 0x44, 0xC4, 0x03, 0x88,  // 1300
  0x82, 0x11, 0x23, 0x03, 0x11, 0x03, 0x88, 0x84, 0xC4, 0x86, 0xFC, 0x00, 0x03, 0x80, 0x83, 0xC0,  // 1310
  0x40, 0xFF, 0x03, 0x80, 0x81, 0xFF, 0x03, 0x80, 0x95, 0xE2, 0x02, 0x04, 0x0C, 0xF0, 0x00, 0x01,  // 1320
  0x07, 0x22, 0x22, 0x21, 0x71, 0x70, 0xD8, 0x8C, 0x07, 0x3F, 0x00, 0x00, 0x80, 0x7F, 0x03, 0x00,  // 1330
  0x90, 0xF8, 0x08, 0x08, 0x0C, 0xFC, 0x0E, 0x0B, 0x09, 0x8E, 0x80, 0x40, 0x60, 0x1F, 0x00, 0x00,  // 1340
  0xC0, 0x02, 0x23, 0x02, 0x22, 0x81, 0xE2, 0x03, 0x00, 0x85, 0x11, 0x10, 0x22, 0x22, 0x23, 0x03,  // 1350
  0x46, 0x85, 0xC4, 0x04, 0x02, 0x02, 0xFE, 0x03, 0x00, 0x85, 0x40, 0x60, 0x20, 0x20, 0x30, 0x03,  // 1360
  0x10, 0x81, 0xFF, 0x07, 0x00, 0x81, 0xFC, 0x07, 0x00, 0x81, 0x01, 0x07, 0x00, 0x81, 0xF8, 0x07,  // 1370
  0x00, 0x81, 0x7F, 0x07, 0x00, 0x81, 0xF0, 0x07, 0x00, 0x97, 0x80, 0x40, 0x00, 0x00, 0x02, 0x00,  // 1380
  0x00, 0x08, 0x00, 0x01, 0x00, 0x00, 0x20, 0x00, 0x00, 0x10, 0x80, 0x00, 0x02, 0x00, 0x00, 0x04,  // 1390
  0x01, 0x03, 0x00, 0x94, 0x10, 0x80, 0x08, 0x00, 0x40, 0x00, 0x04, 0x10, 0x02, 0x24, 0x04, 0x04,  // 13A0
  0x02, 0x00, 0x41, 0x00, 0x4A, 0x20, 0x11, 0x10, 0x04, 0x00, 0x82, 0x22, 0x80, 0x04, 0x00, 0x85,  // 13B0
  0x48, 0x04, 0x20, 0x80, 0x40, 0x05, 0x00, 0x88, 0x04, 0x02, 0x01, 0x00, 0x00, 0x08, 0x20, 0x90,  // 13C0
  0x06, 0x00, 0xAA, 0x08, 0x04, 0x40, 0x12, 0x10, 0x00, 0x10, 0x12, 0x08, 0x20, 0x04, 0x48, 0x08,  // 13D0
  0x08, 0x04, 0x00, 0x88, 0x04, 0x92, 0x40, 0x21, 0x20, 0x00, 0x00, 0x24, 0x42, 0x00, 0x24, 0x01,  // 13E0
  0x18, 0x82, 0x00, 0x24, 0x50, 0x82, 0x24, 0x04, 0x04, 0x02, 0x00, 0x20, 0x90, 0x05, 0x00, 0x81,  // 13F0
  0x02, 0x04, 0x00, 0x86, 0x88, 0x00, 0x00, 0x04, 0x20, 0x40, 0x06, 0x00, 0x84, 0x01, 0x00, 0x00,  // 1400
  0x04, 0x03, 0x00, 0x85, 0x02, 0x40, 0x00, 0x00, 0xA0, 0x03, 0x00, 0x90, 0x40, 0x00, 0x08, 0x02,  // 1410
  0x00, 0x00, 0x10, 0x04, 0x00, 0x04, 0x00, 0x20, 0x00, 0x02, 0x00, 0x10, 0x05, 0x00, 0x02, 0x10,  // 1420
  0x86, 0x08, 0x20, 0x00, 0x00, 0x08, 0x80, 0x03, 0x40, 0x81, 0x88, 0x12, 0x00, 0x81, 0x08, 0x0B,  // 1430
  0x00, 0x8A, 0x40, 0x00, 0x40, 0x04, 0x08, 0x40, 0x44, 0x20, 0x02, 0x10, 0x03, 0x00, 0x89, 0x01,  // 1440
  0x20, 0x20, 0x10, 0x41, 0x00, 0x00, 0x10, 0x00, 0x03, 0x80, 0x82, 0x10, 0x44, 0x0A, 0x00, 0x89,  // 1450
  0x01, 0x00, 0x00, 0x40, 0x00, 0x50, 0x00, 0x00, 0x28, 0x03, 0x00, 0x81, 0x90, 0x08, 0x00, 0x82,  // 1460
  0x48, 0x84, 0x06, 0x00, 0x82, 0x11, 0x20, 0x06, 0x00, 0x82, 0x24, 0xC2, 0x06, 0x00, 0x82, 0x11,  // 1470
  0x20, 0x07, 0x00, 0x81, 0x84, 0x06, 0x00, 0x82, 0x10, 0x20, 0x06, 0x00, 0x82, 0x22, 0x41, 0x06,  // 1480
  0x00, 0x82, 0x04, 0x08, 0x0E, 0x00, 0x82, 0x91, 0x20, 0x06, 0x00, 0x82, 0x01, 0x88, 0x07, 0x00,  // 1490
  0x81, 0x80, 0x07, 0x00, 0x81, 0x08, 0x06, 0x00, 0x82, 0x20, 0x40, 0x06, 0x00, 0x81, 0x44, 0x08,  // 14A0
  0x00, 0x81, 0x04, 0x06, 0x00, 0x82, 0x92, 0x21, 0x06, 0x00, 0x82, 0x04, 0x08, 0x06, 0x00, 0x82,  // 14B0
  0x40, 0x20, 0x06, 0x00, 0x00, 0x89, 0x00, 0x03, 0x0F, 0x1F, 0x3E, 0x39, 0x7B, 0x77, 0x00, 0x03,  // 14C0
  0xFF, 0x81, 0x00, 0x03, 0xFF, 0x89, 0x00, 0xC0, 0xC3, 0xC7, 0x0F, 0xCE, 0xDE, 0xDD, 0x00, 0x03,  // 14D0
  0xFF, 0x95, 0x80, 0x7F, 0xFF, 0xFF, 0x00, 0xF0, 0xF0, 0xF1, 0x03, 0xF3, 0xF7, 0xF7, 0x00, 0x3F,  // 14E0
  0xFF, 0xFF, 0xE0, 0x9F, 0xBF, 0x7F, 0x00, 0x03, 0xFC, 0x81, 0x00, 0x03, 0xFC, 0x82, 0x00, 0x01,  // 14F0
  0x02, 0x07, 0x02, 0x0E, 0x02, 0x1D, 0xA0, 0x00, 0xC0, 0xF0, 0xF1, 0x39, 0xB9, 0xDD, 0xDC, 0x00,  // 1500
  0x78, 0x84, 0x72, 0x4A, 0x72, 0x4A, 0x84, 0x77, 0x77, 0x7B, 0x39, 0x3E, 0x1F, 0x0F, 0x03, 0x00,  // 1510
  0xF8, 0xFE, 0xFF, 0x0F, 0xF3, 0xFB, 0xFD, 0x04, 0x1D, 0x85, 0x9C, 0x9D, 0xDD, 0xDD, 0xC0, 0x03,  // 1520
  0xFF, 0x81, 0x00, 0x03, 0xFF, 0x81, 0x07, 0x03, 0xE7, 0x81, 0x07, 0x03, 0xE7, 0x81, 0x70, 0x03,  // 1530
  0x77, 0x81, 0x70, 0x03, 0x77, 0x81, 0x00, 0x03, 0xFC, 0x81, 0x1C, 0x03, 0xDC, 0x81, 0x1D, 0x03,  // 1540
  0x3B, 0x03, 0x77, 0x82, 0xEE, 0xDC, 0x03, 0xEE, 0x03, 0x77, 0x82, 0x3B, 0x78, 0x06, 0x00, 0x82,  // 1550
  0x80, 0x00, 0x03, 0x7F, 0x81, 0x00, 0x03, 0x7F, 0x95, 0x1D, 0xFD, 0xFB, 0xF3, 0x0F, 0xFF, 0xFE,  // 1560
  0xF8, 0xDD, 0xDD, 0xDE, 0x8E, 0x8F, 0x07, 0x03, 0x00, 0xC0, 0xFF, 0xFF, 0x7F, 0x80, 0x03, 0xFF,  // 1570
  0x90, 0x07, 0xF7, 0xF7, 0xF3, 0x03, 0xF1, 0xF0, 0xF0, 0x71, 0x7F, 0xBF, 0x9F, 0xE0, 0xFF, 0xFF,  // 1580
  0x3F, 0x02, 0xDC, 0x02, 0xDD, 0x81, 0x1D, 0x03, 0xFF, 0x85, 0xEE, 0xEF, 0xDD, 0xDD, 0xDC, 0x03,  // 1590
  0xB9, 0x85, 0x3B, 0xFB, 0xFD, 0xFD, 0x01, 0x03, 0xFF, 0x02, 0x80, 0x03, 0xC0, 0x03, 0xE0, 0x7F,  // 15A0
  0x00, 0x7F, 0x00, 0x7F, 0x00, 0x63, 0x00, 0x00, 0x7F, 0x00, 0x7F, 0x00, 0x7F, 0x00, 0x7F, 0x00,  // 15B0
  0x7F, 0x00, 0x55, 0x00, 0x00, 0x08, 0x00, 0x07, 0xFF, 0x81, 0xFE, 0x07, 0xFF, 0x81, 0x00, 0x0F,  // 15C0
  0xFE, 0x8F, 0x00, 0x81, 0xC3, 0xE7, 0xFF, 0xFF, 0xC1, 0x81, 0x91, 0x91, 0x99, 0x81, 0xC3, 0xC3,  // 15D0
  0x81, 0x03, 0x99, 0x85, 0x81, 0xC3, 0xC3, 0x81, 0x99, 0x02, 0x81, 0x02, 0x99, 0x04, 0x8F, 0x02,  // 15E0
  0x81, 0x84, 0xFF, 0x7E, 0x3C, 0x18, 0x04, 0x00, 0x81, 0x78, 0x04, 0xFC, 0x84, 0x78, 0x2A, 0x00,  // 15F0
  0x78, 0x04, 0xFC, 0x84, 0x78, 0x54, 0x00, 0x1E, 0x04, 0x3F, 0x84, 0x1E, 0x54, 0x00, 0x1E, 0x04,  // 1600
  0x3F, 0xA3, 0x1E, 0x2A, 0x00, 0x1E, 0x7F, 0x3F, 0x7F, 0x3F, 0x5E, 0x00, 0x00, 0x1E, 0x3F, 0x7F,  // 1610
  0x3F, 0x7F, 0x1E, 0x40, 0x00, 0x00, 0x02, 0x78, 0xFE, 0xFC, 0xFE, 0xFC, 0x78, 0x00, 0x00, 0x7A,  // 1620
  0xFC, 0xFE, 0xFC, 0xFE, 0x78, 0x00, 0x07, 0x00, 0x81, 0xFF, 0x07, 0x00, 0x81, 0x01, 0x07, 0x00,  // 1630
  0x81, 0xFF, 0x0F, 0x01, 0x84, 0xFF, 0x81, 0xC3, 0xE7, 0x1E, 0xFF, 0x83, 0x7E, 0x3C, 0x18, 0x04,  // 1640
  0x00, 0xC0, 0x78, 0xCC, 0xB5, 0xAC, 0xC4, 0x78, 0x00, 0x00, 0x78, 0xCC, 0xB4, 0xAD, 0xC4, 0x78,  // 1650
  0x00, 0x00, 0x1E, 0x33, 0xAD, 0x35, 0x23, 0x1E, 0x00, 0x00, 0x1E, 0x33, 0x2D, 0xB5, 0x23, 0x1E,  // 1660
  0x00, 0x00, 0x1E, 0x33, 0x2D, 0x25, 0x2B, 0x1E, 0x00, 0x08, 0x1E, 0x33, 0x2D, 0x25, 0x2B, 0x1E,  // 1670
  0x00, 0x04, 0x20, 0x00, 0x78, 0xD4, 0xA4, 0xB4, 0xCC, 0x78, 0x10, 0x00, 0x78, 0xD4, 0xA4, 0xB4,  // 1680
  0xCC, 0x78, 0x00, 0x07, 0x00, 0x21, 0xFF, 0x8E, 0x81, 0xC3, 0xE7, 0xFF, 0xFF, 0xC1, 0xBF, 0xF1,  // 1690
  0xFF, 0xFF, 0xE7, 0xFF, 0xC3, 0xBD, 0x03, 0xFF, 0x86, 0xE7, 0xFF, 0xC3, 0xBD, 0xFF, 0xE7, 0x03,  // 16A0
  0xFF, 0x81, 0x8F, 0x03, 0xFF, 0x86, 0xF1, 0xFF, 0xFF, 0x7E, 0x3C, 0x18, 0x05, 0x00, 0xBF, 0x30,  // 16B0
  0x49, 0x51, 0x3B, 0x07, 0xFE, 0x00, 0x00, 0x30, 0x48, 0x51, 0x3B, 0x07, 0xFE, 0x00, 0x00, 0x0C,  // 16C0
  0x92, 0x8A, 0xDC, 0xE0, 0x7F, 0x00, 0x00, 0x0C, 0x12, 0x8A, 0xDC, 0xE0, 0x7F, 0x00, 0x40, 0x4C,  // 16D0
  0x52, 0x5A, 0x54, 0x60, 0x70, 0x38, 0x40, 0x4C, 0x52, 0x5A, 0x54, 0x60, 0x70, 0x3C, 0x3C, 0x0E,  // 16E0
  0x06, 0x2A, 0x5A, 0x4A, 0x32, 0x02, 0x1C, 0x0E, 0x06, 0x2A, 0x5A, 0x4A, 0x32, 0x02, 0x00, 0x7F,  // 16F0
  0x00, 0x11, 0x00, 0x00, 0x3C, 0x42, 0x99, 0xA1, 0xA1, 0x99, 0x42, 0x3C, 0x7C, 0xFC, 0xE0, 0xF8,  // 1700
  0x7C, 0x1C, 0xFC, 0xF8, 0x7C, 0xFC, 0xC0, 0xF8, 0xF8, 0xC0, 0xFC, 0x7C, 0x7C, 0xFC, 0xC0, 0xDC,  // 1710
  0xDC, 0xCC, 0xFC, 0x7C, 0x38, 0x38, 0x7C, 0x5C, 0x5C, 0xCE, 0xBE, 0xBE, 0x00, 0x00, 0x00, 0x00,  // 1720
  0x00, 0x00, 0x00, 0x00, 0x18, 0x3C, 0x3C, 0x3C, 0x18, 0x00, 0x18, 0x00, 0x6C, 0x6C, 0x48, 0x00,  // 1730
  0x00, 0x00, 0x00, 0x00, 0x6C, 0xFE, 0x6C, 0x6C, 0x6C, 0xFE, 0x6C, 0x00, 0x18, 0x3E, 0x58, 0x3C,  // 1740
  0x1A, 0x7C, 0x18, 0x00, 0x00, 0xC6, 0xCC, 0x18, 0x30, 0x66, 0xC6, 0x00, 0x70, 0xC8, 0xC8, 0x70,  // 1750
  0x9A, 0x8C, 0x76, 0x00, 0x18, 0x18, 0x10, 0x00, 0x00, 0x00, 0x00, 0x00, 0x0C, 0x18, 0x30, 0x30,  // 1760
  0x30, 0x18, 0x0C, 0x00, 0x30, 0x18, 0x0C, 0x0C, 0x0C, 0x18, 0x30, 0x00, 0x00, 0x18, 0x5A, 0x3C,  // 1770
  0x3C, 0x5A, 0x18, 0x00, 0x00, 0x18, 0x18, 0x7E, 0x18, 0x18, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,  // 1780
  0x18, 0x18, 0x08, 0x10, 0x00, 0x00, 0x00, 0x7C, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,  // 1790
  0x00, 0x18, 0x18, 0x00, 0x00, 0x06, 0x0C, 0x18, 0x30, 0x60, 0xC0, 0x00, 0x38, 0x4C, 0xC6, 0xC6,  // 17A0
  0xC6, 0x64, 0x38, 0x00, 0x18, 0x38, 0x18, 0x18, 0x18, 0x18, 0x7E, 0x00, 0x7C, 0xC6, 0x0E, 0x3C,  // 17B0
  0x78, 0xE0, 0xFE, 0x00, 0x7E, 0x0C, 0x18, 0x3C, 0x06, 0xC6, 0x7C, 0x00, 0x1C, 0x3C, 0x6C, 0xCC,  // 17C0
  0xFE, 0x0C, 0x0C, 0x00, 0xFC, 0xC0, 0xFC, 0x06, 0x06, 0xC6, 0x7C, 0x00, 0x3C, 0x60, 0xC0, 0xFC,  // 17D0
  0xC6, 0xC6, 0x7C, 0x00, 0xFE, 0xC6, 0x0C, 0x18, 0x30, 0x30, 0x30, 0x00, 0x7C, 0xC6, 0xC6, 0x7C,  // 17E0
  0xC6, 0xC6, 0x7C, 0x00, 0x7C, 0xC6, 0xC6, 0x7E, 0x06, 0x0C, 0x78, 0x00, 0x00, 0x18, 0x18, 0x00,  // 17F0
  0x18, 0x18, 0x00, 0x00, 0x00, 0x18, 0x18, 0x00, 0x18, 0x18, 0x08, 0x10, 0x0C, 0x18, 0x30, 0x60,  // 1800
  0x30, 0x18, 0x0C, 0x00, 0x00, 0x00, 0x7C, 0x00, 0x7C, 0x00, 0x00, 0x00, 0x60, 0x30, 0x18, 0x0C,  // 1810
  0x18, 0x30, 0x60, 0x00, 0x7C, 0xC6, 0x06, 0x1C, 0x30, 0x00, 0x30, 0x00, 0x7C, 0xC6, 0x06, 0x66,  // 1820
  0xD6, 0xD6, 0x7C, 0x00, 0x38, 0x6C, 0xC6, 0xC6, 0xFE, 0xC6, 0xC6, 0x00, 0xFC, 0xC6, 0xC6, 0xFC,  // 1830
  0xC6, 0xC6, 0xFC, 0x00, 0x3C, 0x66, 0xC0, 0xC0, 0xC0, 0x66, 0x3C, 0x00, 0xF8, 0xCC, 0xC6, 0xC6,  // 1840
  0xC6, 0xCC, 0xF8, 0x00, 0xFE, 0xC0, 0xC0, 0xF8, 0xC0, 0xC0, 0xFE, 0x00, 0xFE, 0xC0, 0xC0, 0xF8,  // 1850
  0xC0, 0xC0, 0xC0, 0x00, 0x3E, 0x60, 0xC0, 0xCE, 0xC6, 0x66, 0x3E, 0x00, 0xC6, 0xC6, 0xC6, 0xFE,  // 1860
  0xC6, 0xC6, 0xC6, 0x00, 0x7E, 0x18, 0x18, 0x18, 0x18, 0x18, 0x7E, 0x00, 0x06, 0x06, 0x06, 0x06,  // 1870
  0x06, 0xC6, 0x7C, 0x00, 0xC6, 0xCC, 0xD8, 0xF0, 0xF8, 0xDC, 0xCE, 0x00, 0xC0, 0xC0, 0xC0, 0xC0,  // 1880
  0xC0, 0xC0, 0xFE, 0x00, 0xC6, 0xEE, 0xFE, 0xFE, 0xD6, 0xC6, 0xC6, 0x00, 0xC6, 0xE6, 0xF6, 0xFE,  // 1890
  0xDE, 0xCE, 0xC6, 0x00, 0x7C, 0xC6, 0xC6, 0xC6, 0xC6, 0xC6, 0x7C, 0x00, 0xFC, 0xC6, 0xC6, 0xC6,  // 18A0
  0xFC, 0xC0, 0xC0, 0x00, 0x7C, 0xC6, 0xC6, 0xC6, 0xDE, 0xCC, 0x76, 0x00, 0xFC, 0xC6, 0xC6, 0xCE,  // 18B0
  0xF8, 0xDC, 0xCE, 0x00, 0x78, 0xCC, 0xC0, 0x7C, 0x06, 0xC6, 0x7C, 0x00, 0x7E, 0x18, 0x18, 0x18,  // 18C0
  0x18, 0x18, 0x18, 0x00, 0xC6, 0xC6, 0xC6, 0xC6, 0xC6, 0xC6, 0x7C, 0x00, 0xC6, 0xC6, 0xC6, 0xEE,  // 18D0
  0x7C, 0x38, 0x10, 0x00, 0xC6, 0xC6, 0xD6, 0xFE, 0xFE, 0x6C, 0x44, 0x00, 0xC6, 0xEE, 0x7C, 0x38,  // 18E0
  0x7C, 0xEE, 0xC6, 0x00, 0x66, 0x66, 0x66, 0x3C, 0x18, 0x18, 0x18, 0x00, 0xFE, 0x0E, 0x1C, 0x38,  // 18F0
  0x70, 0xE0, 0xFE, 0x00, 0xF8, 0xC0, 0xC0, 0xC0, 0xC0, 0xC0, 0xF8, 0x00, 0x00, 0x80, 0x40, 0x20,  // 1900
  0x10, 0x08, 0x00, 0x00, 0xF8, 0x18, 0x18, 0x18, 0x18, 0x18, 0xF8, 0x00, 0x00, 0x00, 0x20, 0x50,  // 1910
  0x88, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xF8, 0x7F, 0x00, 0x21, 0x00,  // 1920
  0x08, 0xFF, 0x00, 0x7F, 0x00, 0x29, 0x00, 0x00, 0x7F, 0x00, 0x21, 0x00, 0x08, 0xFF, 0x00, 0x02,  // 1930
  0xFF, 0x05, 0xF0, 0x81, 0xFF, 0x02, 0xF8, 0x05, 0x00, 0x81, 0xE0, 0x02, 0xF8, 0x03, 0xFC, 0x03,  // 1940
  0xF6, 0x08, 0x78, 0x02, 0x1F, 0x06, 0x03, 0x82, 0xF1, 0xF3, 0x06, 0xC3, 0x02, 0xFF, 0x06, 0xC0,  // 1950
  0x81, 0xE7, 0x02, 0xF3, 0x02, 0xF1, 0x03, 0xF0, 0x02, 0x80, 0x02, 0xC1, 0x02, 0xE3, 0x83, 0xF7,  // 1960
  0x7F, 0xF0, 0x02, 0xE0, 0x02, 0xC0, 0x02, 0x80, 0x82, 0x00, 0xFF, 0x05, 0xF0, 0x02, 0xFF, 0x81,  // 1970
  0xE0, 0x05, 0x00, 0x02, 0xF8, 0x03, 0xF3, 0x03, 0xF1, 0x02, 0xF0, 0x02, 0x78, 0x81, 0x79, 0x04,  // 1980
  0xF9, 0x81, 0xF8, 0x02, 0x03, 0x04, 0xE3, 0x02, 0xFF, 0x07, 0xC3, 0x81, 0x81, 0x06, 0xC0, 0x02,  // 1990
  0xFF, 0x07, 0xF0, 0x82, 0xE0, 0x7F, 0x07, 0x3E, 0x04, 0x78, 0x02, 0x00, 0x02, 0x78, 0x08, 0x00,  // 19A0
  0x00, 0xB8, 0x60, 0xF0, 0x41, 0x03, 0x0D, 0x00, 0x0D, 0xC3, 0x00, 0x50, 0x8D, 0x43, 0x78, 0x77,  // 19B0
  0x79, 0x5D, 0x03, 0xAD, 0xD1, 0x10, 0x50, 0x55, 0x64, 0x65, 0x40, 0x51, 0x2D, 0x35, 0x24, 0x22,  // 19C0
  0x81, 0x81, 0x43, 0x55, 0x41, 0x05, 0x75, 0xFB, 0x40, 0x00, 0x52, 0x68, 0x8D, 0xC5, 0x22, 0x2E,  // 19D0
  0xCD, 0x0C, 0x14, 0x94, 0x35, 0xD1, 0x43, 0x7B, 0x51, 0x01, 0xE1, 0x56, 0x45, 0x63, 0x50, 0x6D,  // 19E0
  0x18, 0x41, 0x8E, 0x5B, 0x5D, 0x1E, 0x98, 0x10, 0xD4, 0x12, 0x34, 0x6E, 0x55, 0xEB, 0x48, 0x47,  // 19F0
  0x5B, 0x04, 0x74, 0x5B, 0x85, 0x4D, 0x83, 0xB6, 0x2D, 0xD1, 0x58, 0x6D, 0x35, 0x92, 0x0E, 0xD8,  // 1A00
  0x42, 0x04, 0x2D, 0x92, 0x45, 0xD7, 0x11, 0x20, 0x06, 0x41, 0x76, 0x63, 0x8D, 0x61, 0xD4, 0x00,  // 1A10
  0xD8, 0x36, 0x98, 0x5D, 0xDD, 0xB4, 0xBB, 0x77, 0xA3, 0x77, 0x0F, 0x56, 0x89, 0x20, 0x00, 0x22,  // 1A20
  0x02, 0x22, 0x02, 0xA8, 0xA0, 0x58, 0xF0, 0x01, 0x4D, 0x37, 0x04, 0x1D, 0x30, 0x1E, 0xAD, 0x4D,  // 1A30
  0x11, 0x06, 0x75, 0x08, 0x4D, 0x7B, 0x57, 0x51, 0xD4, 0x75, 0x61, 0xD3, 0xBA, 0x2E, 0xAE, 0xAD,  // 1A40
  0x83, 0x69, 0x4D, 0x2E, 0xD4, 0x75, 0x5B, 0x41, 0x50, 0x1D, 0xD2, 0x78, 0x4B, 0x18, 0x56, 0x0D,  // 1A50
  0x6E, 0x08, 0xAD, 0x23, 0xBE, 0x07, 0x55, 0x35, 0x35, 0x34, 0xD2, 0x4E, 0xD8, 0xD2, 0x56, 0x41,  // 1A60
  0xC5, 0x06, 0x63, 0x3B, 0x11, 0x8D, 0x5B, 0x4D, 0xB8, 0x7B, 0xBD, 0x48, 0x44, 0x01, 0x54, 0x11,  // 1A70
  0xD4, 0x6E, 0xD5, 0x8E, 0x55, 0x00, 0x55, 0xED, 0x2D, 0xB8, 0x18, 0x35, 0xD6, 0xD0, 0x56, 0x61,  // 1A80
  0xC8, 0xED, 0xED, 0xD6, 0x38, 0x15, 0x55, 0x81, 0x4D, 0x51, 0x51, 0x63, 0xE0, 0x82, 0x59, 0x75,  // 1A90
  0x51, 0x6C, 0x60, 0x14, 0x53, 0x03, 0xAE, 0x55, 0x23, 0x11, 0x10, 0x05, 0x56, 0x0D, 0x58, 0x21,  // 1AA0
  0x02, 0x08, 0x08, 0x00, 0x88, 0x00, 0xA0, 0x88, 0xB8, 0x50, 0x7D, 0x37, 0x30, 0x80, 0x77, 0x77,  // 1AB0
  0x77, 0x53, 0x15, 0xE2, 0xE0, 0x74, 0x55, 0x55, 0x61, 0xAD, 0xD5, 0x5D, 0x83, 0x55, 0x55, 0x55,  // 1AC0
  0xB4, 0x51, 0x55, 0x55, 0x40, 0x55, 0x6D, 0xE1, 0xD5, 0x55, 0x55, 0xD5, 0x6D, 0x55, 0x35, 0x82,  // 1AD0
  0x58, 0x55, 0x55, 0x55, 0x51, 0x55, 0xD9, 0x00, 0x54, 0x55, 0x61, 0x55, 0x6D, 0x55, 0x14, 0x00,  // 1AE0
  0x85, 0x54, 0x8D, 0x55, 0x51, 0x21, 0xD8, 0x00, 0x02, 0x94, 0x31, 0x88, 0x63, 0x0D, 0x2E, 0x00,  // 1AF0
  0x35, 0x58, 0xED, 0x00, 0x5E, 0x01, 0xD5, 0x00, 0x06, 0x54, 0x11, 0x00, 0x55, 0x73, 0x38, 0x00,  // 1B00
  0x34, 0x58, 0x6D, 0x03, 0x56, 0x55, 0x57, 0x03, 0x08, 0x55, 0x51, 0x00, 0x88, 0x55, 0x55, 0x00,  // 1B10
  0x34, 0xA2, 0x2D, 0x0D, 0x00, 0x56, 0x45, 0x03, 0x0B, 0x50, 0x75, 0x05, 0x0D, 0x21, 0x82, 0x8D,  // 1B20
  0x0D, 0xA0, 0x21, 0x02, 0x08, 0x08, 0x00, 0x02, 0x02, 0xA0, 0xA8, 0x58, 0x38, 0xDD, 0xC0, 0x02,  // 1B30
  0x00, 0x00, 0x00, 0x31, 0x50, 0x55, 0x83, 0xC3, 0x00, 0x02, 0x40, 0x04, 0x58, 0x55, 0xD0, 0x5E,  // 1B40
  0x03, 0x00, 0x10, 0x01, 0x50, 0x55, 0xA3, 0x65, 0xCD, 0x00, 0xD5, 0xD0, 0x6D, 0x85, 0x0C, 0x8E,  // 1B50
  0x56, 0x03, 0x46, 0x8B, 0x98, 0xD5, 0x36, 0x01, 0x88, 0xD0, 0x00, 0x0D, 0x54, 0x15, 0xD8, 0x0D,  // 1B60
  0xD0, 0x60, 0x83, 0x05, 0x51, 0xD5, 0x6D, 0x35, 0x64, 0x53, 0x74, 0xB5, 0x54, 0x55, 0xB5, 0xD5,  // 1B70
  0xB5, 0x14, 0x55, 0xD5, 0x55, 0x55, 0xD5, 0x56, 0x45, 0x45, 0x6D, 0x55, 0x55, 0x55, 0x55, 0x5B,  // 1B80
  0x81, 0x21, 0x16, 0x88, 0x55, 0x45, 0x65, 0x55, 0x41, 0x0D, 0x08, 0x74, 0x55, 0x71, 0x15, 0x52,  // 1B90
  0x80, 0xF5, 0x00, 0x55, 0x55, 0x6D, 0x48, 0x07, 0x00, 0x58, 0x43, 0x55, 0x57, 0x85, 0x8F, 0x35,  // 1BA0
  0x00, 0x60, 0x8D, 0x55, 0x55, 0x01, 0x02, 0x22, 0x00, 0x00, 0x0A, 0x20, 0xA2, 0x40, 0xB0, 0xF0,  // 1BB0
  0x31, 0xF4, 0x3D, 0xD0, 0xD0, 0x1E, 0xD1, 0x94, 0x4D, 0x55, 0xD8, 0x45, 0x87, 0x7B, 0x2D, 0x59,  // 1BC0
  0xB5, 0x61, 0x87, 0x11, 0x02, 0x12, 0xD2, 0x50, 0x05, 0x1E, 0x36, 0x4E, 0x43, 0xE0, 0x84, 0x57,  // 1BD0
  0x45, 0x0B, 0x0B, 0xC5, 0x1E, 0x44, 0xFB, 0x5A, 0x41, 0x53, 0x80, 0x12, 0x45, 0xBB, 0x60, 0x97,  // 1BE0
  0x8D, 0xEE, 0xD0, 0xD3, 0x52, 0xE0, 0x8D, 0x55, 0x4D, 0x3B, 0x6E, 0x2E, 0x2D, 0xB4, 0xF4, 0xA2,  // 1BF0
  0x85, 0xEE, 0x13, 0x78, 0x46, 0xDB, 0x18, 0x5E, 0x35, 0x85, 0xED, 0x2D, 0x81, 0x63, 0xE4, 0x98,  // 1C00
  0x8D, 0xD1, 0x92, 0x10, 0x8D, 0x1D, 0xB4, 0x6D, 0x51, 0x60, 0xE3, 0x4D, 0xD1, 0x06, 0x08, 0x91,  // 1C10
  0x6D, 0x93, 0x50, 0xB8, 0x87, 0x7B, 0x37, 0x56, 0x7D, 0x45, 0xA4, 0xD7, 0x76, 0xAC, 0x45, 0xAF,  // 1C20
  0x15, 0x12, 0xCD, 0x16, 0x15, 0xD1, 0x82, 0x55, 0x09, 0x20, 0x88, 0x20, 0x82, 0x00, 0x20, 0xA2,  // 1C30
  0xB0, 0x80, 0x68, 0x0D, 0x40, 0x0F, 0x0D, 0x11, 0x74, 0x03, 0x50, 0x35, 0x5D, 0x75, 0x75, 0x35,  // 1C40
  0x60, 0x01, 0xA0, 0x55, 0x55, 0x55, 0x55, 0x75, 0x80, 0x34, 0x50, 0x55, 0x55, 0x56, 0x55, 0x18,  // 1C50
  0xD0, 0x40, 0x97, 0x55, 0x15, 0x58, 0x18, 0xD0, 0x21, 0x50, 0x55, 0x55, 0x08, 0x20, 0x00, 0x58,  // 1C60
  0xDD, 0x54, 0x95, 0x05, 0x00, 0xF4, 0x00, 0x54, 0x55, 0x65, 0x55, 0x75, 0xF7, 0x55, 0x03, 0x55,  // 1C70
  0x55, 0x8D, 0x55, 0x21, 0x62, 0x55, 0x41, 0x55, 0x15, 0x75, 0x55, 0x0D, 0x80, 0x55, 0x80, 0xB5,  // 1C80
  0x48, 0x55, 0x95, 0x05, 0x70, 0x15, 0x00, 0x06, 0x13, 0x5A, 0x65, 0x01, 0x54, 0x05, 0x00, 0x41,  // 1C90
  0x05, 0x6C, 0x5D, 0x0D, 0x55, 0x01, 0xD0, 0x5E, 0x08, 0x78, 0x55, 0x05, 0x66, 0x0D, 0x54, 0x1B,  // 1CA0
  0x00, 0x54, 0x55, 0x71, 0x83, 0x01, 0x56, 0xED, 0x00, 0x25, 0x5A, 0x21, 0x02, 0x00, 0x20, 0x82,  // 1CB0
  0x00, 0x02, 0xA0, 0x78, 0x70, 0x78, 0x0D, 0x00, 0x38, 0x03, 0x00, 0xE0, 0x00, 0x50, 0x35, 0x00,  // 1CC0
  0x44, 0x00, 0x00, 0x00, 0x34, 0xAD, 0xD5, 0x00, 0xB8, 0x23, 0x00, 0x40, 0x5B, 0x51, 0x15, 0x00,  // 1CD0
  0x44, 0x0D, 0x00, 0xB4, 0x54, 0xAD, 0x55, 0x03, 0xB8, 0x35, 0x00, 0x45, 0x1B, 0x52, 0x55, 0x00,  // 1CE0
  0x80, 0x14, 0x4D, 0x81, 0x54, 0xA3, 0x55, 0x03, 0x00, 0x88, 0xB8, 0x1D, 0x18, 0x5E, 0x6D, 0x0D,  // 1CF0
  0x37, 0x1C, 0x40, 0x08, 0x00, 0x55, 0xB5, 0x75, 0xE1, 0xD8, 0x80, 0x0D, 0x00, 0x56, 0x55, 0x55,  // 1D00
  0x81, 0xD7, 0x00, 0x02, 0x00, 0x55, 0x55, 0x55, 0x41, 0x55, 0xC0, 0xDD, 0x8D, 0x55, 0x55, 0x61,  // 1D10
  0x5D, 0xD5, 0x50, 0x55, 0xDD, 0x55, 0x55, 0x80, 0x55, 0x59, 0x63, 0x55, 0x55, 0x58, 0x15, 0x03,  // 1D20
  0x4A, 0x5D, 0x50, 0x89, 0x55, 0xA3, 0x45, 0x00, 0x50, 0x58, 0x63, 0x00, 0x88, 0x50, 0x01, 0x00,  // 1D30
  0x00, 0x88, 0x00, 0x20, 0x00, 0xA0, 0x78, 0x48, 0xE0, 0xDD, 0x00, 0xDD, 0x40, 0x34, 0x77, 0x03,  // 1D40
  0x50, 0x55, 0x43, 0x55, 0x03, 0xD6, 0x16, 0x8E, 0xA4, 0x85, 0x5D, 0x54, 0x00, 0x55, 0x01, 0x00,  // 1D50
  0x51, 0x41, 0x15, 0x56, 0x03, 0x56, 0xD0, 0x40, 0x57, 0x4D, 0x45, 0x88, 0x00, 0x18, 0x60, 0x53,  // 1D60
  0x55, 0xB5, 0x50, 0x03, 0x0C, 0xD4, 0x5D, 0x85, 0x55, 0x05, 0xD5, 0xDE, 0xE1, 0x55, 0x58, 0x01,  // 1D70
  0x56, 0x71, 0x15, 0x88, 0x5D, 0x95, 0x63, 0x00, 0x58, 0x6D, 0xD5, 0x00, 0x56, 0x35, 0xDE, 0x10,  // 1D80
  0x94, 0x51, 0x15, 0x00, 0x55, 0x05, 0x55, 0xE3, 0x55, 0x6D, 0xD8, 0x8C, 0x56, 0x7B, 0x55, 0x50,  // 1D90
  0xAD, 0x15, 0xA0, 0xFB, 0x55, 0x60, 0x15, 0x54, 0x55, 0xD5, 0x70, 0x5D, 0x88, 0x80, 0xD5, 0x58,  // 1DA0
  0x55, 0x85, 0x63, 0x15, 0x0E, 0x00, 0x5A, 0x63, 0x58, 0x75, 0x50, 0x35, 0x78, 0x77, 0x57, 0x80,  // 1DB0
  0x57, 0x21, 0xA0, 0x08, 0x20, 0x22, 0x22, 0x00, 0xA2, 0x58, 0xB0, 0xE8, 0x0D, 0x34, 0xB0, 0xB7,  // 1DC0
  0xC7, 0xE0, 0xEC, 0x5D, 0x35, 0xE1, 0x44, 0xD1, 0x12, 0x34, 0x51, 0x55, 0x11, 0x10, 0xB5, 0x2E,  // 1DD0
  0xED, 0x51, 0x84, 0x55, 0x31, 0x04, 0x06, 0x75, 0x81, 0x6D, 0xCB, 0x96, 0x1D, 0xD4, 0x51, 0x11,  // 1DE0
  0x1E, 0xB8, 0x10, 0x55, 0xC5, 0x55, 0x60, 0x20, 0xFB, 0x40, 0x63, 0x98, 0xB5, 0x2E, 0xB4, 0x47,  // 1DF0
  0xAD, 0x53, 0x51, 0x6F, 0x45, 0x38, 0xD8, 0x62, 0xD1, 0x96, 0x20, 0x52, 0x51, 0x04, 0x6D, 0x43,  // 1E00
  0x24, 0xED, 0xDD, 0xA0, 0x15, 0xD0, 0xB6, 0x8D, 0x3B, 0x82, 0x1B, 0x50, 0x05, 0x11, 0xD8, 0x42,  // 1E10
  0x05, 0x41, 0xED, 0x6D, 0x4D, 0x04, 0x54, 0xD3, 0xBE, 0x8D, 0x51, 0x51, 0x1D, 0x38, 0x61, 0x2D,  // 1E20
  0xD8, 0xD2, 0x6E, 0x94, 0x05, 0x2D, 0x1E, 0x42, 0x87, 0x14, 0x82, 0x55, 0x41, 0x40, 0x0B, 0x77,  // 1E30
  0x35, 0x7B, 0x77, 0x59, 0x01, 0x20, 0x02, 0x22, 0x82, 0x20, 0x22, 0xA8, 0x40, 0x40, 0xE8, 0x75,  // 1E40
  0xD3, 0x04, 0xC3, 0x4E, 0x37, 0x0D, 0x92, 0x21, 0x24, 0xDD, 0x2E, 0x11, 0x61, 0x38, 0x55, 0x3D,  // 1E50
  0x75, 0x15, 0x41, 0x44, 0x4E, 0x47, 0x58, 0x59, 0x18, 0xD6, 0xBE, 0x11, 0x34, 0x12, 0x94, 0x2D,  // 1E60
  0xEC, 0xD5, 0xD4, 0xEE, 0x49, 0xD1, 0x5D, 0x01, 0xB8, 0x98, 0x1B, 0xB4, 0x5D, 0x84, 0x68, 0xDD,  // 1E70
  0xED, 0x60, 0xD1, 0x48, 0x28, 0x0D, 0x50, 0x85, 0x51, 0x83, 0x14, 0x5D, 0x43, 0xD0, 0x94, 0x71,  // 1E80
  0xA0, 0xDD, 0xD9, 0xB6, 0x10, 0x24, 0x61, 0x2D, 0x3D, 0x86, 0x23, 0x45, 0x2F, 0x41, 0x57, 0x71,  // 1E90
  0x08, 0x41, 0xD1, 0xB8, 0x35, 0x1E, 0x56, 0x2D, 0x51, 0x51, 0x20, 0xED, 0x49, 0x4B, 0x5B, 0x75,  // 1EA0
  0x54, 0x14, 0x70, 0xB6, 0x50, 0x50, 0x94, 0x15, 0xD4, 0xD8, 0x22, 0x49, 0x27, 0x2D, 0x58, 0x49,  // 1EB0
  0x1D, 0x6C, 0x77, 0xD0, 0xD1, 0x72, 0x57, 0x81, 0x08, 0x02, 0x22, 0x80, 0x88, 0x20, 0xA2, 0x60,  // 1EC0
  0x60, 0xF0, 0x1D, 0xF0, 0x4D, 0x03, 0x4D, 0x74, 0x8C, 0xA3, 0x09, 0x6D, 0x50, 0x10, 0x11, 0x2D,  // 1ED0
  0x31, 0x50, 0xCD, 0x55, 0x2D, 0x4D, 0x5D, 0x78, 0x44, 0x97, 0x91, 0x85, 0x41, 0x4B, 0x44, 0x23,  // 1EE0
  0x35, 0x66, 0x51, 0xF8, 0x8E, 0x1D, 0x81, 0x34, 0xE1, 0x58, 0x2D, 0x2C, 0x45, 0x49, 0x34, 0xD5,  // 1EF0
  0x8E, 0x50, 0xD1, 0x39, 0x52, 0x38, 0x49, 0x24, 0x0D, 0x6D, 0x85, 0xDD, 0x2D, 0x44, 0x8D, 0x3B,  // 1F00
  0x7A, 0x91, 0xC1, 0x56, 0x04, 0x51, 0x41, 0xC4, 0x6E, 0x6C, 0x01, 0x18, 0x79, 0x84, 0x10, 0x05,  // 1F10
  0xB8, 0x51, 0x4D, 0x83, 0xE0, 0x40, 0x43, 0x31, 0x0D, 0x6E, 0x11, 0xEE, 0x60, 0x93, 0x10, 0x2E,  // 1F20
  0x76, 0x50, 0xED, 0xBB, 0x83, 0xD7, 0x8D, 0xDB, 0xE8, 0x9D, 0xB1, 0x4C, 0x43, 0x85, 0x41, 0x20,  // 1F30
  0x8D, 0x5B, 0xED, 0x51, 0x50, 0x35, 0x5E, 0x77, 0xF8, 0x56, 0x89, 0x20, 0x20, 0x0A, 0x88, 0x22,  // 1F40
  0x20, 0x28, 0x40, 0x88, 0xC0, 0x35, 0x00, 0x00, 0x00, 0x0D, 0x00, 0x00, 0x50, 0xD5, 0x00, 0x00,  // 1F50
  0x40, 0x35, 0x00, 0x00, 0x54, 0x55, 0x03, 0x00, 0x50, 0xD5, 0x00, 0x00, 0x55, 0x55, 0x0D, 0x00,  // 1F60
  0x54, 0x55, 0x03, 0x40, 0x55, 0x55, 0x35, 0x00, 0x55, 0x55, 0x0D, 0x50, 0x55, 0x55, 0xD5, 0x40,  // 1F70
  0x55, 0x55, 0x35, 0x54, 0x55, 0x55, 0x55, 0x53, 0x55, 0x55, 0xD5, 0x55, 0x55, 0x55, 0x95, 0x55,  // 1F80
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x05, 0x56, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x01, 0x58,  // 1F90
  0x55, 0x55, 0x55, 0x56, 0x55, 0x55, 0x00, 0x60, 0x55, 0x55, 0x55, 0x5B, 0x55, 0x15, 0x00, 0x80,  // 1FA0
  0x55, 0x55, 0x55, 0x60, 0x55, 0x05, 0x00, 0x00, 0x56, 0x55, 0x15, 0x80, 0x55, 0x0D, 0x00, 0x00,  // 1FB0
  0x58, 0x55, 0x05, 0x00, 0x56, 0x0D, 0x00, 0x00, 0x60, 0x55, 0x01, 0x00, 0x58, 0x01, 0x00, 0x00,  // 1FC0
  0x80, 0x80, 0x00, 0x00, 0xA0, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF,  // 1FD0
  0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF,  // 1FE0
  0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF   // 1FF0
};
