
#include <stdlib.h>
#include <string.h>
#include <malloc.h>
#include "png.h"
#ifdef SDL
#include "sdl.h"
#else
#include <pspkernel.h>
#include <pspdisplay.h>
#include <pspgu.h>
#endif
#include "video.h"
#include "system.h"
#include "text.h"
#include "config.h"
#include "def.h"

VIDEO_MODE video_mode = VM_NONE;

#ifdef SDL

BOOL          sdl_init       = FALSE;
SDL_Surface  *main_surface   = (SDL_Surface *)0;
SDL_Surface  *draw_buffer    = (SDL_Surface *)0;
BOOL          draw_buffer_locked;
unsigned char screen_buffer[256 * 192];

VIDEO_BUFFER sdl_draw = {
  (void *)0,
  0,
  480,
  272,
  (void *)0,
  0
};

const VIDEO_BUFFER sdl_screen = {
  (void *)screen_buffer,
  256,
  256,
  192,
  (void *)0,
  0
};

#else

unsigned int ALIGN(16) list[262144];

#define SCREEN_BUFFER (unsigned char *)(0x44000000 + (512 * 272 * 4))

unsigned char save_screen[256 * 192];

BOOL gu_init = FALSE;
int  gu_disp;

const VIDEO_BUFFER gu_draw[2][2] = {
  {
    {
      (void *)(0x44000000 + (512 * 272 * 2)),
      512 * 2,
      480,
      272,
      512,
      272
    },
    {
      (void *)(0x44000000),
      512 * 2,
      480,
      272,
      512,
      272
    }
  },
  {
    {
      (void *)(0x44000000 + (512 * 272 * 4)),
      512 * 4,
      480,
      272,
      512,
      272
    },
    {
      (void *)(0x44000000),
      512 * 4,
      480,
      272,
      512,
      272
    }
  }
};

const VIDEO_BUFFER gu_screen[2] = {
  {
    (void *)SCREEN_BUFFER,
    256,
    256,
    192,
    256,
    256
  },
  {
    (void *)save_screen, // menu mode, return saved screen
    256,
    256,
    192,
    256,
    256
  }
};

#endif


void Video_Init(void)
{
#ifdef SDL

  if(!sdl_init)
  {
    if((SDL_InitSubSystem(SDL_INIT_VIDEO) < 0)) exit(0);
    main_surface = SDL_SetVideoMode(480, 272, 0, SDL_HWSURFACE | SDL_ANYFORMAT);
    if(!main_surface) exit(0);
    sdl_init = TRUE;
  }
#else

  if(!gu_init)
  {
    sceGuInit();
    gu_init = TRUE;
  }

#endif
}


void Video_Quit(void)
{
#ifdef SDL

  if(draw_buffer) { SDL_FreeSurface(draw_buffer); draw_buffer = (SDL_Surface *)0; }
  if(sdl_init)    { SDL_QuitSubSystem(SDL_INIT_VIDEO); sdl_init = FALSE; }

#else

  if(gu_init) { sceGuTerm(); gu_init = FALSE; }

#endif

  video_mode = VM_NONE;
}

void Video_SetMode(VIDEO_MODE mode)
{
#ifdef SDL

  if(!sdl_init) Video_Init();
  if(mode == video_mode) return;
  if(draw_buffer) SDL_FreeSurface(draw_buffer);
  switch(mode)
  {
    case VM_EMULATION:
      draw_buffer = SDL_CreateRGBSurface(SDL_SWSURFACE, 480, 272, 16, 0x001F, 0x07E0, 0xF800, 0x0000);
      if(!draw_buffer) exit(0);
      SDL_SetAlpha(draw_buffer, SDL_RLEACCEL, 0);
      draw_buffer_locked = FALSE;
      break;
    case VM_MENU:
      draw_buffer = SDL_CreateRGBSurface(SDL_SWSURFACE, 480, 272, 32, 0x000000FF, 0x0000FF00, 0x00FF0000, 0xFF000000);
      if(!draw_buffer) exit(0);
      SDL_SetAlpha(draw_buffer, SDL_RLEACCEL, 0);
      draw_buffer_locked = FALSE;
      break;
    default:
      exit(0);
      break;
  }

  video_mode = mode;

#else

  if(!gu_init) Video_Init();
  if(mode == video_mode) return;

  sceGuDisplay(GU_FALSE);

  switch(mode)
  {
    case VM_EMULATION:
      sceGuStart(GU_DIRECT, list);
	    sceGuDrawBuffer(GU_PSM_5650, (void *)(512 * 272 * 2), 512);
	    sceGuDispBuffer(480, 272, (void *)0, 512);
      sceGuFinish();
      sceGuSync(0, 0);
      sceGuStart(GU_DIRECT, list);
	    sceGuDrawBuffer(GU_PSM_5650, (void *)(512 * 272 * 2), 512);
	    sceGuDispBuffer(480, 272, (void *)0, 512);
	    sceGuOffset(2048 - (480 / 2), 2048 - (272 / 2));
	    sceGuViewport(2048, 2048, 480, 272);
      sceGuDisable(GU_ALPHA_TEST);
      sceGuDisable(GU_DEPTH_TEST);
      sceGuDisable(GU_SCISSOR_TEST);
      sceGuDisable(GU_BLEND);
      sceGuDisable(GU_CULL_FACE);
	    sceGuDisable(GU_CLIP_PLANES);
      sceGuDisable(GU_LIGHTING);
      sceGuDisable(GU_DITHER);
      sceGuDisable(GU_COLOR_LOGIC_OP);
	    sceGuShadeModel(GU_FLAT);
      sceGuEnable(GU_TEXTURE_2D);
      sceGuTexMode(GU_PSM_T8, 0, 0, GU_FALSE);
      sceGuClutMode(GU_PSM_5650, 0, 255, 0);
      sceGuTexFunc(GU_TFX_REPLACE, GU_TCC_RGB);
      sceGuTexWrap(GU_CLAMP, GU_CLAMP);
      sceGuClearColor(0);
      sceGuClear(GU_COLOR_BUFFER_BIT);
      sceGuFinish();
      sceGuSync(0, 0);
      break;
    case VM_MENU:
      // saving the screen
      if(video_mode == VM_EMULATION) memcpy(save_screen, SCREEN_BUFFER, 256 * 192);
      else memset(save_screen, 0, 256 * 192);
      sceGuStart(GU_DIRECT, list);
	    sceGuDrawBuffer(GU_PSM_8888, (void *)(512 * 272 * 4), 512);
	    sceGuDispBuffer(480, 272, (void *)0, 512);
      sceGuFinish();
      sceGuSync(0, 0);
      sceGuStart(GU_DIRECT, list);
	    sceGuDrawBuffer(GU_PSM_8888, (void *)(512 * 272 * 4), 512);
	    sceGuDispBuffer(480, 272, (void *)0, 512);
	    sceGuOffset(2048 - (480 / 2), 2048 - (272 / 2));
	    sceGuViewport(2048, 2048, 480, 272);
      sceGuDisable(GU_DEPTH_TEST);
      sceGuDisable(GU_LIGHTING);
	    sceGuDisable(GU_CULL_FACE);
	    sceGuDisable(GU_CLIP_PLANES);
      sceGuDisable(GU_DITHER);
      sceGuDisable(GU_COLOR_LOGIC_OP);
	    sceGuEnable(GU_SCISSOR_TEST);
	    sceGuScissor(0, 0, 480, 272);
	    sceGuEnable(GU_ALPHA_TEST);
	    sceGuAlphaFunc(GU_GREATER, 0, 0xFF);
	    sceGuShadeModel(GU_FLAT);
	    sceGuEnable(GU_TEXTURE_2D);
	    sceGuEnable(GU_BLEND);
	    sceGuBlendFunc(GU_ADD, GU_SRC_ALPHA, GU_ONE_MINUS_SRC_ALPHA, 0, 0);
	    sceGuTexMode(GU_PSM_8888, 0, 0, GU_FALSE);
	    sceGuTexFunc(GU_TFX_REPLACE, GU_TCC_RGBA);
	    sceGuTexFilter(GU_LINEAR, GU_LINEAR);
      sceGuTexWrap(GU_CLAMP, GU_CLAMP);
      sceGuClearColor(0);
      sceGuClear(GU_COLOR_BUFFER_BIT);
      sceGuFinish();
      sceGuSync(0, 0);
      break;
    default:
      exit(0);
      break;
  }

  sceDisplayWaitVblankStart();
  sceGuDisplay(GU_TRUE);

  gu_disp    = 0;
  video_mode = mode;

#endif

  Video_Clear();
}

#ifdef SDL

const VIDEO_BUFFER *Video_GetDrawBuffer(void)
{

  if(sdl_init && draw_buffer)
  {
    if(!draw_buffer_locked && SDL_MUSTLOCK(draw_buffer))
    {
      if(SDL_LockSurface(draw_buffer) < 0) exit(0);
      draw_buffer_locked = TRUE;
    }
    sdl_draw.Data  = draw_buffer->pixels;
    sdl_draw.Pitch = draw_buffer->pitch;
    return &sdl_draw;
  }

  return (const VIDEO_BUFFER *)0;
}

#endif

void Video_Clear(void)
{
  unsigned char *dst;
  int            y;

#ifdef SDL

  int n;

  if(!sdl_init) return;

  if(video_mode == VM_EMULATION)
  {
    memset(screen_buffer, 0, 256 * 192);
    n = 2;
  }
  else n = 4;

  if(draw_buffer)
  {
    if(draw_buffer_locked && SDL_MUSTLOCK(draw_buffer))
    {
      if(SDL_LockSurface(draw_buffer) < 0) exit(0);
      draw_buffer_locked = TRUE;
    }
    for(y = 0, dst = (unsigned char *)draw_buffer->pixels; y < draw_buffer->h; dst += draw_buffer->pitch, y++)
      memset(dst, 0, draw_buffer->w * n);
  }

#else

  const VIDEO_BUFFER *buf;

  if(!gu_init) return;

  if(video_mode == VM_EMULATION)
  {
    memset(SCREEN_BUFFER, 0, 256 * 192);
    buf = Video_GetDrawBuffer();
    for(y = 0, dst = (unsigned char *)buf->Data; y < 272; dst += buf->Pitch, y++) memset(dst, 0, 480 * 2);
    Video_Flip(FALSE);
    buf = Video_GetDrawBuffer();
    for(y = 0, dst = (unsigned char *)buf->Data; y < 272; dst += buf->Pitch, y++) memset(dst, 0, 480 * 2);
  }
  else
  {
    buf = Video_GetDrawBuffer();
    for(y = 0, dst = (unsigned char *)buf->Data; y < 272; dst += buf->Pitch, y++) memset(dst, 0, 480 * 4);
    Video_Flip(FALSE);
    buf = Video_GetDrawBuffer();
    for(y = 0, dst = (unsigned char *)buf->Data; y < 272; dst += buf->Pitch, y++) memset(dst, 0, 480 * 4);
  }

#endif
}

#ifndef SDL

static int get_next_power2(int width)
{
	int b = width;
	int n;
	
  for(n = 0; b != 0; n++) b >>= 1;
	b = 1 << n;
	if(b == 2 * width) b >>= 1;
	
  return b;
}

#endif

VIDEO_BUFFER *Video_Alloc(int w, int h)
{
#ifdef SDL

  VIDEO_BUFFER *buf;
  SDL_Surface  *mem;

  if(!sdl_init || video_mode != VM_MENU) return (VIDEO_BUFFER *)0;
  mem = SDL_CreateRGBSurface(SDL_SWSURFACE, w, h, 32, 0x000000FF, 0x0000FF00, 0x00FF0000, 0xFF000000);
  if(!mem) exit(0);
  buf = (VIDEO_BUFFER *)malloc(sizeof(VIDEO_BUFFER));
  if(!buf) exit(0);
  if(buf->Locked = SDL_MUSTLOCK(mem)) { if(SDL_LockSurface(mem) < 0) exit(0); }
  buf->Data       = mem->pixels;
  buf->Pitch      = mem->pitch;
  buf->Width      = w;
  buf->Height     = h;
  buf->SDLSurface = (void *)mem;
  memset(buf->Data, 0, buf->Pitch * buf->Height);

  return buf;

#else

  VIDEO_BUFFER *buf;

  if(!gu_init || video_mode != VM_MENU) return (VIDEO_BUFFER *)0;
  buf = (VIDEO_BUFFER *)malloc(sizeof(VIDEO_BUFFER));
  if(!buf) return (VIDEO_BUFFER *)0;
  buf->Pitch  = buf->Tw = get_next_power2(w);
  if(buf->Pitch & 0x0F) { buf->Pitch &= ~0x0F; buf->Pitch += 0x10; }
  buf->Pitch *= 4;
  buf->Th     = get_next_power2(h);
  buf->Data   = memalign(16, buf->Pitch * buf->Th);
  if(!buf->Data) return free(buf), (VIDEO_BUFFER *)0;
  buf->Width  = w;
  buf->Height = h;
  memset(buf->Data, 0, buf->Pitch * buf->Th);

  return buf;

#endif
}

void Video_Free(VIDEO_BUFFER *buf)
{
#ifdef SDL

  if(buf)
  {
    if(buf->SDLSurface) SDL_FreeSurface(buf->SDLSurface);
    free(buf);
  }

#else

  if(buf)
  {
    if(buf->Data) free(buf->Data);
    free(buf);
  }

#endif
}

static char          msg[MAX_STRING];
static unsigned long msg_time, msg_wait = 0;
static int           msg_erase = 0;
static BOOL          msg_first_frame;

void Video_ShowMessage(const char *message, unsigned long time)
{
  strncpy(msg, message, MAX_STRING);
#ifdef SDL
  msg_erase = 1;
  msg_wait  = time;
#else
  msg_erase = 2;
  msg_wait  = time * 1000;
#endif
  msg_first_frame = TRUE;
}

#ifndef SDL

typedef struct _GU_VERTEX
{
	unsigned short u, v;
	short          x, y, z;
} GU_VERTEX;

#endif

void Video_BlitEmulation(void)
{
#ifdef SDL

  int                 x, y;
  unsigned char      *dst, *src;
  const VIDEO_BUFFER *buf;

  if(!sdl_init || video_mode != VM_EMULATION) return;

  buf = Video_GetDrawBuffer();

  if(msg_erase)
  {
    for(y = 0, dst = (unsigned char *)buf->Data + (260 * buf->Pitch); y < 10; dst += buf->Pitch, y++)
      memset(dst, 0, 480 * 2);
    msg_erase = 0;
  }

  src = screen_buffer;
  dst = (unsigned char *)buf->Data + (480 - 256) + (((272 - 192) / 2) * buf->Pitch);
  for(y = 0; y < 192; y++)
  {
    for(x = 0; x < 256; x++) ((unsigned short *)dst)[x] = (unsigned short)Render_Palette[src[x]];
    dst += buf->Pitch;
    src += 256;
  }

  if(msg_wait)
  {
    Text_SetFontColor(FontType, FontInGameColor[0], FontInGameColor[1]);
    Text_Draw(FontType, msg, 4, 260, 0);
    if(msg_first_frame)
    { msg_time = SDL_GetTicks(); msg_first_frame = FALSE; }
    else
    {
      unsigned long t, d;
      t = SDL_GetTicks();
      d = t - msg_time;
      msg_time = t;
      if(msg_wait <= d) { msg_wait  = 0; msg_erase = 1; }
      else              { msg_wait -= d; }
    }
  }

#else

  int        sj, di, dj, tf;
  short      x, y, w, h;
  GU_VERTEX *v, *vptr;

  if(!gu_init || video_mode != VM_EMULATION) return;

  if(msg_erase)
  {
    const VIDEO_BUFFER *buf;
    unsigned char      *dst;

    buf = Video_GetDrawBuffer();
    for(y = 0, dst = (unsigned char *)buf->Data + (260 * buf->Pitch); y < 10; dst += buf->Pitch, y++)
      memset(dst, 0, 480 * 2);
    msg_erase--;
  }

  sceGuStart(GU_DIRECT, list);
  sceGuTexImage(0, 256, 256, 256, SCREEN_BUFFER);
  sceGuClutLoad(4, (void *)Render_Palette);
  sceGuTexScale(1.0f / 256.0f, 1.0f / 256.0f);
  sceGuTexOffset(0, 0);
  sceGuTexWrap(GU_CLAMP, GU_CLAMP);
  sceGuTexOffset(0, 0);
  tf = ScreenSmoothing ? GU_LINEAR : GU_NEAREST;
  sceGuTexFilter(tf, tf);

  v    = (GU_VERTEX *)sceGuGetMemory(2 * (256 / 64) * sizeof(GU_VERTEX));
  vptr = v;

  if(System.Flags & SF_GAME_GEAR) // game gear
  {
    switch(RenderMode)
    {
      case RENDER_MODE_NORMAL:
        x  = (480 - 160) / 2; y = (272 - 144) / 2;
        w  = 160;             h = 144;
        di = 64;
        break;
      case RENDER_MODE_WIDE:
        x  = (480 - 420) / 2; y = 0;
        w  = 390;             h = 272;
        di = 156;
        break;
      case RENDER_MODE_FULL:
        x  = 0;   y = 0;
        w  = 480; h = 272;
        di = 192;
        break;
      default:
        x  = (480 - 302) / 2; y = 0;
        w  = 302;             h = 272;
        di = 121;
        break;
    }

    for(sj = dj = 0; (sj + 64) < 160; dj += di, sj += 64)
    {
      vptr[0].u = sj + 49;           vptr[0].v = 24;
      vptr[0].x = x + dj;            vptr[0].y = y;
      vptr[0].z = 0;
      vptr[1].u = sj + 49 + 64;      vptr[1].v = 144 + 24;
      vptr[1].x = x + dj + di;       vptr[1].y = y + h;
      vptr[1].z = 0;    
      vptr += 2;
    }
    if(sj < 160)
    {  
      vptr[0].u = sj + 49;           vptr[0].v = 24;
      vptr[0].x = x + dj;            vptr[0].y = y;
      vptr[0].z = 0;
      vptr[1].u = 160 + 49;          vptr[1].v = 144 + 24;
      vptr[1].x = x + w;             vptr[1].y = y + h;
      vptr[1].z = 0;    
      vptr += 2;
    }
  }
  else // master system
  {
    switch(RenderMode)
    {
      case RENDER_MODE_NORMAL:
        x  = (480 - 256) / 2; y = (272 - 192) / 2;
        w  = 256;             h = 192;
        di = 64;
        break;
      case RENDER_MODE_WIDE:
        x  = (480 - 420) / 2; y = 0;
        w  = 420;             h = 272;
        di = 105;
        break;
      case RENDER_MODE_FULL:
        x  = 0;   y = 0;
        w  = 480; h = 272;
        di = 120;
        break;
      default:
        x  = (480 - 364) / 2; y = 0;
        w  = 364;             h = 272;
        di = 91;
        break;
    }

    for(sj = dj = 0; (sj + 64) < 256; dj += di, sj += 64)
    {
      vptr[0].u = sj;                vptr[0].v = 0;
      vptr[0].x = x + dj;            vptr[0].y = y;
      vptr[0].z = 0;
      vptr[1].u = sj + 64;           vptr[1].v = 192;
      vptr[1].x = x + dj + di;       vptr[1].y = y + h;
      vptr[1].z = 0;    
      vptr += 2;
    }
    if(sj < 256)
    {  
      vptr[0].u = sj;                vptr[0].v = 0;
      vptr[0].x = x + dj;            vptr[0].y = y;
      vptr[0].z = 0;
      vptr[1].u = 256;               vptr[1].v = 192;
      vptr[1].x = x + w;             vptr[1].y = y + h;
      vptr[1].z = 0;    
      vptr += 2;
    }
  }

  sceGuDrawArray(GU_SPRITES, GU_TEXTURE_16BIT | GU_VERTEX_16BIT | GU_TRANSFORM_2D, vptr - v, 0, v);

  sceGuFinish();
  sceGuSync(0, 0);

  if(msg_wait)
  {
    Text_SetFontColor(FontType, FontInGameColor[0], FontInGameColor[1]);
    Text_Draw(FontType, msg, 4, 260, 0);
    if(msg_first_frame)
    { msg_time = sceKernelLibcClock(); msg_first_frame = FALSE; }
    else
    {
      unsigned long t, d;
      t = sceKernelLibcClock();
      d = t - msg_time;
      msg_time = t;
      if(msg_wait <= d) { msg_wait  = 0; msg_erase = 2; }
      else              { msg_wait -= d; }
    }
  }

#endif
}

void Video_Blit(VIDEO_BUFFER *src, int x, int y, int w, int h, BOOL alpha)
{
#ifdef SDL

  SDL_Rect r;

  if(!sdl_init || !src) return;

  if(draw_buffer_locked) SDL_UnlockSurface(draw_buffer);
  if(src->Locked)        SDL_UnlockSurface((SDL_Surface *)src->SDLSurface);

  if(w <= 0) w = src->Width;
  if(h <= 0) h = src->Height;

  r.x = x; r.y = y; r.w = w; r.h = h;
  SDL_SetAlpha((SDL_Surface *)src->SDLSurface, alpha ? SDL_SRCALPHA : SDL_RLEACCEL, 0);
  SDL_BlitSurface((SDL_Surface *)src->SDLSurface, NULL, draw_buffer, &r);

  if(src->Locked = SDL_MUSTLOCK(((SDL_Surface *)src->SDLSurface)))
  { if(SDL_LockSurface((SDL_Surface *)src->SDLSurface) < 0) exit(0); }

#else

  if(!gu_init || !src) return;

  if(w <= 0) w = src->Width;
  if(h <= 0) h = src->Height;

  sceGuStart(GU_DIRECT, list);

  if(alpha || w != src->Width || h != src->Height)
  {
    int        j = 0, slice = 64, j2 = 0, slice2;
    GU_VERTEX *v;

    sceGuTexImage(0, src->Tw, src->Th, src->Tw, src->Data);
    sceGuTexScale(1.0f / (float)src->Tw, 1.0f / (float)src->Th);
    sceGuTexOffset(0, 0);

    while(j < src->Width)
    {
	    v = (GU_VERTEX *)sceGuGetMemory(2 * sizeof(GU_VERTEX));
      if(j + slice > src->Width) slice = src->Width - j;
      slice2 = (slice * w) / src->Width;
	    v[0].u = j;
	    v[0].v = 0;
	    v[0].x = x + j2;
	    v[0].y = y;
	    v[0].z = 0;
	    v[1].u = j + slice;
      v[1].v = src->Height;
	    v[1].x = x + j2 + slice2;
      v[1].y = y + h;
	    v[1].z = 0;
	    sceGuDrawArray(GU_SPRITES, GU_TEXTURE_16BIT | GU_VERTEX_16BIT | GU_TRANSFORM_2D, 2, 0, v);
	    j  += slice;
      j2 += slice2;
    }
  }
  else
  {
    const VIDEO_BUFFER *dst;
    dst = Video_GetDrawBuffer();
    sceGuCopyImage(GU_PSM_8888, 0, 0, src->Width, src->Height, src->Tw, src->Data, x, y, dst->Tw, dst->Data);
  }

  	
	sceGuFinish();
	sceGuSync(0, 0);

#endif
}

VIDEO_BUFFER *Video_LoadImage(const char *name)
{
  VIDEO_BUFFER  *img;
  png_structp    png_ptr;
  png_infop      info_ptr;
  unsigned int   sig_read = 0;
  png_uint_32    width, height, x, y;
  int            bit_depth, color_type, interlace_type;
  unsigned long *line;
  unsigned char *dst;
  FILE          *fp;

  fp = fopen(name, "rb");
  if(!fp) return (VIDEO_BUFFER *)0;
  png_ptr = png_create_read_struct(PNG_LIBPNG_VER_STRING, NULL, NULL, NULL);
  if(!png_ptr) return fclose(fp), (VIDEO_BUFFER *)0;
  info_ptr = png_create_info_struct(png_ptr);
  if(!info_ptr) return png_destroy_read_struct(&png_ptr, NULL, NULL), fclose(fp), (VIDEO_BUFFER *)0;
  if(setjmp(png_jmpbuf(png_ptr))) return png_destroy_read_struct(&png_ptr, &info_ptr, NULL), fclose(fp), (VIDEO_BUFFER *)0;
  png_init_io(png_ptr, fp);
  png_set_sig_bytes(png_ptr, sig_read);
  png_read_info(png_ptr, info_ptr);
  png_get_IHDR(png_ptr, info_ptr, &width, &height, &bit_depth, &color_type, &interlace_type, NULL, NULL);
  png_set_strip_16(png_ptr);
  png_set_packing(png_ptr);
  if(color_type == PNG_COLOR_TYPE_PALETTE) png_set_palette_to_rgb(png_ptr);
  if(color_type == PNG_COLOR_TYPE_GRAY && bit_depth < 8) png_set_gray_1_2_4_to_8(png_ptr);
  if(png_get_valid(png_ptr, info_ptr, PNG_INFO_tRNS)) png_set_tRNS_to_alpha(png_ptr);
  png_set_filler(png_ptr, 0xFF, PNG_FILLER_AFTER);

  img = Video_Alloc(width, height);
  if(!img) return png_destroy_read_struct(&png_ptr, &info_ptr, NULL), fclose(fp), (VIDEO_BUFFER *)0;

  line = (unsigned long *)malloc(width * 4);
  if(!line) return Video_Free(img), png_destroy_read_struct(&png_ptr, &info_ptr, NULL), fclose(fp), (VIDEO_BUFFER *)0;

  dst = (unsigned char *)img->Data;
  for(y = 0; y < height; y++)
  {
	  png_read_row(png_ptr, (unsigned char *)line, NULL);
	  for(x = 0; x < width; x++)
    {
		  unsigned long color = line[x];
      ((unsigned long *)dst)[x] = color;
	  }
    dst += img->Pitch;
  }

  free(line);
  png_read_end(png_ptr, info_ptr);
  png_destroy_read_struct(&png_ptr, &info_ptr, NULL);
  fclose(fp);

  return img;
}
